# coding: utf-8

"""
    Metadata API

    The Metadata API has operations that retrieve configuration details pertaining to the different eBay marketplaces. In addition to marketplace information, the API also has operations that get information that helps sellers list items on eBay.  # noqa: E501

    OpenAPI spec version: v1.10.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MotorsListingPolicy(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'category_id': 'str',
        'category_tree_id': 'str',
        'deposit_supported': 'bool',
        'ebay_motors_pro_ad_format_enabled': 'str',
        'ebay_motors_pro_auto_accept_enabled': 'bool',
        'ebay_motors_pro_auto_decline_enabled': 'bool',
        'ebay_motors_pro_best_offer_enabled': 'str',
        'ebay_motors_pro_company_name_enabled': 'bool',
        'ebay_motors_pro_contact_by_address_enabled': 'bool',
        'ebay_motors_pro_contact_by_email_enabled': 'bool',
        'ebay_motors_pro_contact_by_phone_enabled': 'bool',
        'ebay_motors_pro_counter_offer_enabled': 'bool',
        'ebay_motors_pro_payment_method_check_out_enabled': 'str',
        'ebay_motors_pro_phone_count': 'int',
        'ebay_motors_pro_seller_contact_details_enabled': 'bool',
        'ebay_motors_pro_shipping_method_enabled': 'bool',
        'ebay_motors_pro_street_count': 'int',
        'epid_supported': 'bool',
        'local_listing_distances': 'list[LocalListingDistance]',
        'local_market_ad_format_enabled': 'str',
        'local_market_auto_accept_enabled': 'bool',
        'local_market_auto_decline_enabled': 'bool',
        'local_market_best_offer_enabled': 'str',
        'local_market_company_name_enabled': 'bool',
        'local_market_contact_by_address_enabled': 'bool',
        'local_market_contact_by_email_enabled': 'bool',
        'local_market_contact_by_phone_enabled': 'bool',
        'local_market_counter_offer_enabled': 'bool',
        'local_market_non_subscription': 'bool',
        'local_market_payment_method_check_out_enabled': 'str',
        'local_market_phone_count': 'int',
        'local_market_premium_subscription': 'bool',
        'local_market_regular_subscription': 'bool',
        'local_market_seller_contact_details_enabled': 'bool',
        'local_market_shipping_method_enabled': 'bool',
        'local_market_speciality_subscription': 'bool',
        'local_market_street_count': 'int',
        'max_granular_fitment_count': 'int',
        'max_item_compatibility': 'int',
        'non_subscription': 'str',
        'premium_subscription': 'str',
        'regular_subscription': 'str',
        'seller_provided_title_supported': 'bool',
        'speciality_subscription': 'str',
        'vin_supported': 'bool',
        'vrm_supported': 'bool'
    }

    attribute_map = {
        'category_id': 'categoryId',
        'category_tree_id': 'categoryTreeId',
        'deposit_supported': 'depositSupported',
        'ebay_motors_pro_ad_format_enabled': 'ebayMotorsProAdFormatEnabled',
        'ebay_motors_pro_auto_accept_enabled': 'ebayMotorsProAutoAcceptEnabled',
        'ebay_motors_pro_auto_decline_enabled': 'ebayMotorsProAutoDeclineEnabled',
        'ebay_motors_pro_best_offer_enabled': 'ebayMotorsProBestOfferEnabled',
        'ebay_motors_pro_company_name_enabled': 'ebayMotorsProCompanyNameEnabled',
        'ebay_motors_pro_contact_by_address_enabled': 'ebayMotorsProContactByAddressEnabled',
        'ebay_motors_pro_contact_by_email_enabled': 'ebayMotorsProContactByEmailEnabled',
        'ebay_motors_pro_contact_by_phone_enabled': 'ebayMotorsProContactByPhoneEnabled',
        'ebay_motors_pro_counter_offer_enabled': 'ebayMotorsProCounterOfferEnabled',
        'ebay_motors_pro_payment_method_check_out_enabled': 'ebayMotorsProPaymentMethodCheckOutEnabled',
        'ebay_motors_pro_phone_count': 'ebayMotorsProPhoneCount',
        'ebay_motors_pro_seller_contact_details_enabled': 'ebayMotorsProSellerContactDetailsEnabled',
        'ebay_motors_pro_shipping_method_enabled': 'ebayMotorsProShippingMethodEnabled',
        'ebay_motors_pro_street_count': 'ebayMotorsProStreetCount',
        'epid_supported': 'epidSupported',
        'local_listing_distances': 'localListingDistances',
        'local_market_ad_format_enabled': 'localMarketAdFormatEnabled',
        'local_market_auto_accept_enabled': 'localMarketAutoAcceptEnabled',
        'local_market_auto_decline_enabled': 'localMarketAutoDeclineEnabled',
        'local_market_best_offer_enabled': 'localMarketBestOfferEnabled',
        'local_market_company_name_enabled': 'localMarketCompanyNameEnabled',
        'local_market_contact_by_address_enabled': 'localMarketContactByAddressEnabled',
        'local_market_contact_by_email_enabled': 'localMarketContactByEmailEnabled',
        'local_market_contact_by_phone_enabled': 'localMarketContactByPhoneEnabled',
        'local_market_counter_offer_enabled': 'localMarketCounterOfferEnabled',
        'local_market_non_subscription': 'localMarketNonSubscription',
        'local_market_payment_method_check_out_enabled': 'localMarketPaymentMethodCheckOutEnabled',
        'local_market_phone_count': 'localMarketPhoneCount',
        'local_market_premium_subscription': 'localMarketPremiumSubscription',
        'local_market_regular_subscription': 'localMarketRegularSubscription',
        'local_market_seller_contact_details_enabled': 'localMarketSellerContactDetailsEnabled',
        'local_market_shipping_method_enabled': 'localMarketShippingMethodEnabled',
        'local_market_speciality_subscription': 'localMarketSpecialitySubscription',
        'local_market_street_count': 'localMarketStreetCount',
        'max_granular_fitment_count': 'maxGranularFitmentCount',
        'max_item_compatibility': 'maxItemCompatibility',
        'non_subscription': 'nonSubscription',
        'premium_subscription': 'premiumSubscription',
        'regular_subscription': 'regularSubscription',
        'seller_provided_title_supported': 'sellerProvidedTitleSupported',
        'speciality_subscription': 'specialitySubscription',
        'vin_supported': 'vinSupported',
        'vrm_supported': 'vrmSupported'
    }

    def __init__(self, category_id=None, category_tree_id=None, deposit_supported=None, ebay_motors_pro_ad_format_enabled=None, ebay_motors_pro_auto_accept_enabled=None, ebay_motors_pro_auto_decline_enabled=None, ebay_motors_pro_best_offer_enabled=None, ebay_motors_pro_company_name_enabled=None, ebay_motors_pro_contact_by_address_enabled=None, ebay_motors_pro_contact_by_email_enabled=None, ebay_motors_pro_contact_by_phone_enabled=None, ebay_motors_pro_counter_offer_enabled=None, ebay_motors_pro_payment_method_check_out_enabled=None, ebay_motors_pro_phone_count=None, ebay_motors_pro_seller_contact_details_enabled=None, ebay_motors_pro_shipping_method_enabled=None, ebay_motors_pro_street_count=None, epid_supported=None, local_listing_distances=None, local_market_ad_format_enabled=None, local_market_auto_accept_enabled=None, local_market_auto_decline_enabled=None, local_market_best_offer_enabled=None, local_market_company_name_enabled=None, local_market_contact_by_address_enabled=None, local_market_contact_by_email_enabled=None, local_market_contact_by_phone_enabled=None, local_market_counter_offer_enabled=None, local_market_non_subscription=None, local_market_payment_method_check_out_enabled=None, local_market_phone_count=None, local_market_premium_subscription=None, local_market_regular_subscription=None, local_market_seller_contact_details_enabled=None, local_market_shipping_method_enabled=None, local_market_speciality_subscription=None, local_market_street_count=None, max_granular_fitment_count=None, max_item_compatibility=None, non_subscription=None, premium_subscription=None, regular_subscription=None, seller_provided_title_supported=None, speciality_subscription=None, vin_supported=None, vrm_supported=None):  # noqa: E501
        """MotorsListingPolicy - a model defined in Swagger"""  # noqa: E501
        self._category_id = None
        self._category_tree_id = None
        self._deposit_supported = None
        self._ebay_motors_pro_ad_format_enabled = None
        self._ebay_motors_pro_auto_accept_enabled = None
        self._ebay_motors_pro_auto_decline_enabled = None
        self._ebay_motors_pro_best_offer_enabled = None
        self._ebay_motors_pro_company_name_enabled = None
        self._ebay_motors_pro_contact_by_address_enabled = None
        self._ebay_motors_pro_contact_by_email_enabled = None
        self._ebay_motors_pro_contact_by_phone_enabled = None
        self._ebay_motors_pro_counter_offer_enabled = None
        self._ebay_motors_pro_payment_method_check_out_enabled = None
        self._ebay_motors_pro_phone_count = None
        self._ebay_motors_pro_seller_contact_details_enabled = None
        self._ebay_motors_pro_shipping_method_enabled = None
        self._ebay_motors_pro_street_count = None
        self._epid_supported = None
        self._local_listing_distances = None
        self._local_market_ad_format_enabled = None
        self._local_market_auto_accept_enabled = None
        self._local_market_auto_decline_enabled = None
        self._local_market_best_offer_enabled = None
        self._local_market_company_name_enabled = None
        self._local_market_contact_by_address_enabled = None
        self._local_market_contact_by_email_enabled = None
        self._local_market_contact_by_phone_enabled = None
        self._local_market_counter_offer_enabled = None
        self._local_market_non_subscription = None
        self._local_market_payment_method_check_out_enabled = None
        self._local_market_phone_count = None
        self._local_market_premium_subscription = None
        self._local_market_regular_subscription = None
        self._local_market_seller_contact_details_enabled = None
        self._local_market_shipping_method_enabled = None
        self._local_market_speciality_subscription = None
        self._local_market_street_count = None
        self._max_granular_fitment_count = None
        self._max_item_compatibility = None
        self._non_subscription = None
        self._premium_subscription = None
        self._regular_subscription = None
        self._seller_provided_title_supported = None
        self._speciality_subscription = None
        self._vin_supported = None
        self._vrm_supported = None
        self.discriminator = None
        if category_id is not None:
            self.category_id = category_id
        if category_tree_id is not None:
            self.category_tree_id = category_tree_id
        if deposit_supported is not None:
            self.deposit_supported = deposit_supported
        if ebay_motors_pro_ad_format_enabled is not None:
            self.ebay_motors_pro_ad_format_enabled = ebay_motors_pro_ad_format_enabled
        if ebay_motors_pro_auto_accept_enabled is not None:
            self.ebay_motors_pro_auto_accept_enabled = ebay_motors_pro_auto_accept_enabled
        if ebay_motors_pro_auto_decline_enabled is not None:
            self.ebay_motors_pro_auto_decline_enabled = ebay_motors_pro_auto_decline_enabled
        if ebay_motors_pro_best_offer_enabled is not None:
            self.ebay_motors_pro_best_offer_enabled = ebay_motors_pro_best_offer_enabled
        if ebay_motors_pro_company_name_enabled is not None:
            self.ebay_motors_pro_company_name_enabled = ebay_motors_pro_company_name_enabled
        if ebay_motors_pro_contact_by_address_enabled is not None:
            self.ebay_motors_pro_contact_by_address_enabled = ebay_motors_pro_contact_by_address_enabled
        if ebay_motors_pro_contact_by_email_enabled is not None:
            self.ebay_motors_pro_contact_by_email_enabled = ebay_motors_pro_contact_by_email_enabled
        if ebay_motors_pro_contact_by_phone_enabled is not None:
            self.ebay_motors_pro_contact_by_phone_enabled = ebay_motors_pro_contact_by_phone_enabled
        if ebay_motors_pro_counter_offer_enabled is not None:
            self.ebay_motors_pro_counter_offer_enabled = ebay_motors_pro_counter_offer_enabled
        if ebay_motors_pro_payment_method_check_out_enabled is not None:
            self.ebay_motors_pro_payment_method_check_out_enabled = ebay_motors_pro_payment_method_check_out_enabled
        if ebay_motors_pro_phone_count is not None:
            self.ebay_motors_pro_phone_count = ebay_motors_pro_phone_count
        if ebay_motors_pro_seller_contact_details_enabled is not None:
            self.ebay_motors_pro_seller_contact_details_enabled = ebay_motors_pro_seller_contact_details_enabled
        if ebay_motors_pro_shipping_method_enabled is not None:
            self.ebay_motors_pro_shipping_method_enabled = ebay_motors_pro_shipping_method_enabled
        if ebay_motors_pro_street_count is not None:
            self.ebay_motors_pro_street_count = ebay_motors_pro_street_count
        if epid_supported is not None:
            self.epid_supported = epid_supported
        if local_listing_distances is not None:
            self.local_listing_distances = local_listing_distances
        if local_market_ad_format_enabled is not None:
            self.local_market_ad_format_enabled = local_market_ad_format_enabled
        if local_market_auto_accept_enabled is not None:
            self.local_market_auto_accept_enabled = local_market_auto_accept_enabled
        if local_market_auto_decline_enabled is not None:
            self.local_market_auto_decline_enabled = local_market_auto_decline_enabled
        if local_market_best_offer_enabled is not None:
            self.local_market_best_offer_enabled = local_market_best_offer_enabled
        if local_market_company_name_enabled is not None:
            self.local_market_company_name_enabled = local_market_company_name_enabled
        if local_market_contact_by_address_enabled is not None:
            self.local_market_contact_by_address_enabled = local_market_contact_by_address_enabled
        if local_market_contact_by_email_enabled is not None:
            self.local_market_contact_by_email_enabled = local_market_contact_by_email_enabled
        if local_market_contact_by_phone_enabled is not None:
            self.local_market_contact_by_phone_enabled = local_market_contact_by_phone_enabled
        if local_market_counter_offer_enabled is not None:
            self.local_market_counter_offer_enabled = local_market_counter_offer_enabled
        if local_market_non_subscription is not None:
            self.local_market_non_subscription = local_market_non_subscription
        if local_market_payment_method_check_out_enabled is not None:
            self.local_market_payment_method_check_out_enabled = local_market_payment_method_check_out_enabled
        if local_market_phone_count is not None:
            self.local_market_phone_count = local_market_phone_count
        if local_market_premium_subscription is not None:
            self.local_market_premium_subscription = local_market_premium_subscription
        if local_market_regular_subscription is not None:
            self.local_market_regular_subscription = local_market_regular_subscription
        if local_market_seller_contact_details_enabled is not None:
            self.local_market_seller_contact_details_enabled = local_market_seller_contact_details_enabled
        if local_market_shipping_method_enabled is not None:
            self.local_market_shipping_method_enabled = local_market_shipping_method_enabled
        if local_market_speciality_subscription is not None:
            self.local_market_speciality_subscription = local_market_speciality_subscription
        if local_market_street_count is not None:
            self.local_market_street_count = local_market_street_count
        if max_granular_fitment_count is not None:
            self.max_granular_fitment_count = max_granular_fitment_count
        if max_item_compatibility is not None:
            self.max_item_compatibility = max_item_compatibility
        if non_subscription is not None:
            self.non_subscription = non_subscription
        if premium_subscription is not None:
            self.premium_subscription = premium_subscription
        if regular_subscription is not None:
            self.regular_subscription = regular_subscription
        if seller_provided_title_supported is not None:
            self.seller_provided_title_supported = seller_provided_title_supported
        if speciality_subscription is not None:
            self.speciality_subscription = speciality_subscription
        if vin_supported is not None:
            self.vin_supported = vin_supported
        if vrm_supported is not None:
            self.vrm_supported = vrm_supported

    @property
    def category_id(self):
        """Gets the category_id of this MotorsListingPolicy.  # noqa: E501

        The unique identifier of the eBay leaf category for which metadata is being returned.  # noqa: E501

        :return: The category_id of this MotorsListingPolicy.  # noqa: E501
        :rtype: str
        """
        return self._category_id

    @category_id.setter
    def category_id(self, category_id):
        """Sets the category_id of this MotorsListingPolicy.

        The unique identifier of the eBay leaf category for which metadata is being returned.  # noqa: E501

        :param category_id: The category_id of this MotorsListingPolicy.  # noqa: E501
        :type: str
        """

        self._category_id = category_id

    @property
    def category_tree_id(self):
        """Gets the category_tree_id of this MotorsListingPolicy.  # noqa: E501

        The unique identifier of the category tree.  # noqa: E501

        :return: The category_tree_id of this MotorsListingPolicy.  # noqa: E501
        :rtype: str
        """
        return self._category_tree_id

    @category_tree_id.setter
    def category_tree_id(self, category_tree_id):
        """Sets the category_tree_id of this MotorsListingPolicy.

        The unique identifier of the category tree.  # noqa: E501

        :param category_tree_id: The category_tree_id of this MotorsListingPolicy.  # noqa: E501
        :type: str
        """

        self._category_tree_id = category_tree_id

    @property
    def deposit_supported(self):
        """Gets the deposit_supported of this MotorsListingPolicy.  # noqa: E501

        This field is returned as <code>true</code> if the corresponding category supports the use of a deposit/down payment on a motor vehicle listing. In an AddItem call, the seller can configure a down payment for a motor vehicle listing using the PaymentDetails container.  # noqa: E501

        :return: The deposit_supported of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._deposit_supported

    @deposit_supported.setter
    def deposit_supported(self, deposit_supported):
        """Sets the deposit_supported of this MotorsListingPolicy.

        This field is returned as <code>true</code> if the corresponding category supports the use of a deposit/down payment on a motor vehicle listing. In an AddItem call, the seller can configure a down payment for a motor vehicle listing using the PaymentDetails container.  # noqa: E501

        :param deposit_supported: The deposit_supported of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._deposit_supported = deposit_supported

    @property
    def ebay_motors_pro_ad_format_enabled(self):
        """Gets the ebay_motors_pro_ad_format_enabled of this MotorsListingPolicy.  # noqa: E501

        Indicates whether or not eBay Motors Pro sellers can use classified ads in this category to sell their vehicles. This element is applicable for eBay Motors Pro users. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:AdFormatEnabledEnum'>eBay API documentation</a>  # noqa: E501

        :return: The ebay_motors_pro_ad_format_enabled of this MotorsListingPolicy.  # noqa: E501
        :rtype: str
        """
        return self._ebay_motors_pro_ad_format_enabled

    @ebay_motors_pro_ad_format_enabled.setter
    def ebay_motors_pro_ad_format_enabled(self, ebay_motors_pro_ad_format_enabled):
        """Sets the ebay_motors_pro_ad_format_enabled of this MotorsListingPolicy.

        Indicates whether or not eBay Motors Pro sellers can use classified ads in this category to sell their vehicles. This element is applicable for eBay Motors Pro users. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:AdFormatEnabledEnum'>eBay API documentation</a>  # noqa: E501

        :param ebay_motors_pro_ad_format_enabled: The ebay_motors_pro_ad_format_enabled of this MotorsListingPolicy.  # noqa: E501
        :type: str
        """

        self._ebay_motors_pro_ad_format_enabled = ebay_motors_pro_ad_format_enabled

    @property
    def ebay_motors_pro_auto_accept_enabled(self):
        """Gets the ebay_motors_pro_auto_accept_enabled of this MotorsListingPolicy.  # noqa: E501

        Indicates whether or not the category supports the Best Offer Auto Accept feature for eBay Motors Pro listings. This element is for eBay Motors Pro users.  # noqa: E501

        :return: The ebay_motors_pro_auto_accept_enabled of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._ebay_motors_pro_auto_accept_enabled

    @ebay_motors_pro_auto_accept_enabled.setter
    def ebay_motors_pro_auto_accept_enabled(self, ebay_motors_pro_auto_accept_enabled):
        """Sets the ebay_motors_pro_auto_accept_enabled of this MotorsListingPolicy.

        Indicates whether or not the category supports the Best Offer Auto Accept feature for eBay Motors Pro listings. This element is for eBay Motors Pro users.  # noqa: E501

        :param ebay_motors_pro_auto_accept_enabled: The ebay_motors_pro_auto_accept_enabled of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._ebay_motors_pro_auto_accept_enabled = ebay_motors_pro_auto_accept_enabled

    @property
    def ebay_motors_pro_auto_decline_enabled(self):
        """Gets the ebay_motors_pro_auto_decline_enabled of this MotorsListingPolicy.  # noqa: E501

        Indicates whether or not the category allows auto-decline for Best Offers for eBay Motors Classified Ad listings. This element is for eBay Motors Pro users.  # noqa: E501

        :return: The ebay_motors_pro_auto_decline_enabled of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._ebay_motors_pro_auto_decline_enabled

    @ebay_motors_pro_auto_decline_enabled.setter
    def ebay_motors_pro_auto_decline_enabled(self, ebay_motors_pro_auto_decline_enabled):
        """Sets the ebay_motors_pro_auto_decline_enabled of this MotorsListingPolicy.

        Indicates whether or not the category allows auto-decline for Best Offers for eBay Motors Classified Ad listings. This element is for eBay Motors Pro users.  # noqa: E501

        :param ebay_motors_pro_auto_decline_enabled: The ebay_motors_pro_auto_decline_enabled of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._ebay_motors_pro_auto_decline_enabled = ebay_motors_pro_auto_decline_enabled

    @property
    def ebay_motors_pro_best_offer_enabled(self):
        """Gets the ebay_motors_pro_best_offer_enabled of this MotorsListingPolicy.  # noqa: E501

        This enumerated value indicates whether or not Best Offer features are supported for eBay Motors Classified Ad listings in this category. This element is for eBay Motors Pro users. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:ClassifiedAdBestOfferEnabledEnum'>eBay API documentation</a>  # noqa: E501

        :return: The ebay_motors_pro_best_offer_enabled of this MotorsListingPolicy.  # noqa: E501
        :rtype: str
        """
        return self._ebay_motors_pro_best_offer_enabled

    @ebay_motors_pro_best_offer_enabled.setter
    def ebay_motors_pro_best_offer_enabled(self, ebay_motors_pro_best_offer_enabled):
        """Sets the ebay_motors_pro_best_offer_enabled of this MotorsListingPolicy.

        This enumerated value indicates whether or not Best Offer features are supported for eBay Motors Classified Ad listings in this category. This element is for eBay Motors Pro users. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:ClassifiedAdBestOfferEnabledEnum'>eBay API documentation</a>  # noqa: E501

        :param ebay_motors_pro_best_offer_enabled: The ebay_motors_pro_best_offer_enabled of this MotorsListingPolicy.  # noqa: E501
        :type: str
        """

        self._ebay_motors_pro_best_offer_enabled = ebay_motors_pro_best_offer_enabled

    @property
    def ebay_motors_pro_company_name_enabled(self):
        """Gets the ebay_motors_pro_company_name_enabled of this MotorsListingPolicy.  # noqa: E501

        Indicates whether this category supports including the company name in the seller's contact information. This element is for eBay Motors Pro users.  # noqa: E501

        :return: The ebay_motors_pro_company_name_enabled of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._ebay_motors_pro_company_name_enabled

    @ebay_motors_pro_company_name_enabled.setter
    def ebay_motors_pro_company_name_enabled(self, ebay_motors_pro_company_name_enabled):
        """Sets the ebay_motors_pro_company_name_enabled of this MotorsListingPolicy.

        Indicates whether this category supports including the company name in the seller's contact information. This element is for eBay Motors Pro users.  # noqa: E501

        :param ebay_motors_pro_company_name_enabled: The ebay_motors_pro_company_name_enabled of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._ebay_motors_pro_company_name_enabled = ebay_motors_pro_company_name_enabled

    @property
    def ebay_motors_pro_contact_by_address_enabled(self):
        """Gets the ebay_motors_pro_contact_by_address_enabled of this MotorsListingPolicy.  # noqa: E501

        Indicates whether this category supports including the address in the seller's contact information. This element is for eBay Motors Pro users.  # noqa: E501

        :return: The ebay_motors_pro_contact_by_address_enabled of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._ebay_motors_pro_contact_by_address_enabled

    @ebay_motors_pro_contact_by_address_enabled.setter
    def ebay_motors_pro_contact_by_address_enabled(self, ebay_motors_pro_contact_by_address_enabled):
        """Sets the ebay_motors_pro_contact_by_address_enabled of this MotorsListingPolicy.

        Indicates whether this category supports including the address in the seller's contact information. This element is for eBay Motors Pro users.  # noqa: E501

        :param ebay_motors_pro_contact_by_address_enabled: The ebay_motors_pro_contact_by_address_enabled of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._ebay_motors_pro_contact_by_address_enabled = ebay_motors_pro_contact_by_address_enabled

    @property
    def ebay_motors_pro_contact_by_email_enabled(self):
        """Gets the ebay_motors_pro_contact_by_email_enabled of this MotorsListingPolicy.  # noqa: E501

        Indicates whether this category supports including an email address in the seller's contact information. This element is for eBay Motors Pro users.  # noqa: E501

        :return: The ebay_motors_pro_contact_by_email_enabled of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._ebay_motors_pro_contact_by_email_enabled

    @ebay_motors_pro_contact_by_email_enabled.setter
    def ebay_motors_pro_contact_by_email_enabled(self, ebay_motors_pro_contact_by_email_enabled):
        """Sets the ebay_motors_pro_contact_by_email_enabled of this MotorsListingPolicy.

        Indicates whether this category supports including an email address in the seller's contact information. This element is for eBay Motors Pro users.  # noqa: E501

        :param ebay_motors_pro_contact_by_email_enabled: The ebay_motors_pro_contact_by_email_enabled of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._ebay_motors_pro_contact_by_email_enabled = ebay_motors_pro_contact_by_email_enabled

    @property
    def ebay_motors_pro_contact_by_phone_enabled(self):
        """Gets the ebay_motors_pro_contact_by_phone_enabled of this MotorsListingPolicy.  # noqa: E501

        Indicates whether this category supports including the telephone in the seller's contact information. This element is for eBay Motors Pro users.  # noqa: E501

        :return: The ebay_motors_pro_contact_by_phone_enabled of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._ebay_motors_pro_contact_by_phone_enabled

    @ebay_motors_pro_contact_by_phone_enabled.setter
    def ebay_motors_pro_contact_by_phone_enabled(self, ebay_motors_pro_contact_by_phone_enabled):
        """Sets the ebay_motors_pro_contact_by_phone_enabled of this MotorsListingPolicy.

        Indicates whether this category supports including the telephone in the seller's contact information. This element is for eBay Motors Pro users.  # noqa: E501

        :param ebay_motors_pro_contact_by_phone_enabled: The ebay_motors_pro_contact_by_phone_enabled of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._ebay_motors_pro_contact_by_phone_enabled = ebay_motors_pro_contact_by_phone_enabled

    @property
    def ebay_motors_pro_counter_offer_enabled(self):
        """Gets the ebay_motors_pro_counter_offer_enabled of this MotorsListingPolicy.  # noqa: E501

        Indicates whether counter offers are allowed on Best Offers for this category in an eBay Motors Classified Ad listing. This element is for eBay Motors Pro users.  # noqa: E501

        :return: The ebay_motors_pro_counter_offer_enabled of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._ebay_motors_pro_counter_offer_enabled

    @ebay_motors_pro_counter_offer_enabled.setter
    def ebay_motors_pro_counter_offer_enabled(self, ebay_motors_pro_counter_offer_enabled):
        """Sets the ebay_motors_pro_counter_offer_enabled of this MotorsListingPolicy.

        Indicates whether counter offers are allowed on Best Offers for this category in an eBay Motors Classified Ad listing. This element is for eBay Motors Pro users.  # noqa: E501

        :param ebay_motors_pro_counter_offer_enabled: The ebay_motors_pro_counter_offer_enabled of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._ebay_motors_pro_counter_offer_enabled = ebay_motors_pro_counter_offer_enabled

    @property
    def ebay_motors_pro_payment_method_check_out_enabled(self):
        """Gets the ebay_motors_pro_payment_method_check_out_enabled of this MotorsListingPolicy.  # noqa: E501

        This enumerated value indicates whether this category supports that the payment method should be displayed to the user for this category in an eBay Motors Classified Ad listing. Even if enabled, checkout may or may not be enabled. This element is for eBay Motors Pro users. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:ClassifiedAdPaymentMethodEnabledEnum'>eBay API documentation</a>  # noqa: E501

        :return: The ebay_motors_pro_payment_method_check_out_enabled of this MotorsListingPolicy.  # noqa: E501
        :rtype: str
        """
        return self._ebay_motors_pro_payment_method_check_out_enabled

    @ebay_motors_pro_payment_method_check_out_enabled.setter
    def ebay_motors_pro_payment_method_check_out_enabled(self, ebay_motors_pro_payment_method_check_out_enabled):
        """Sets the ebay_motors_pro_payment_method_check_out_enabled of this MotorsListingPolicy.

        This enumerated value indicates whether this category supports that the payment method should be displayed to the user for this category in an eBay Motors Classified Ad listing. Even if enabled, checkout may or may not be enabled. This element is for eBay Motors Pro users. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:ClassifiedAdPaymentMethodEnabledEnum'>eBay API documentation</a>  # noqa: E501

        :param ebay_motors_pro_payment_method_check_out_enabled: The ebay_motors_pro_payment_method_check_out_enabled of this MotorsListingPolicy.  # noqa: E501
        :type: str
        """

        self._ebay_motors_pro_payment_method_check_out_enabled = ebay_motors_pro_payment_method_check_out_enabled

    @property
    def ebay_motors_pro_phone_count(self):
        """Gets the ebay_motors_pro_phone_count of this MotorsListingPolicy.  # noqa: E501

        Indicates the number of phone numbers that can be included through contact information for this category. This element is for eBay Motors Pro users.  # noqa: E501

        :return: The ebay_motors_pro_phone_count of this MotorsListingPolicy.  # noqa: E501
        :rtype: int
        """
        return self._ebay_motors_pro_phone_count

    @ebay_motors_pro_phone_count.setter
    def ebay_motors_pro_phone_count(self, ebay_motors_pro_phone_count):
        """Sets the ebay_motors_pro_phone_count of this MotorsListingPolicy.

        Indicates the number of phone numbers that can be included through contact information for this category. This element is for eBay Motors Pro users.  # noqa: E501

        :param ebay_motors_pro_phone_count: The ebay_motors_pro_phone_count of this MotorsListingPolicy.  # noqa: E501
        :type: int
        """

        self._ebay_motors_pro_phone_count = ebay_motors_pro_phone_count

    @property
    def ebay_motors_pro_seller_contact_details_enabled(self):
        """Gets the ebay_motors_pro_seller_contact_details_enabled of this MotorsListingPolicy.  # noqa: E501

        Indicates whether this category allows seller-level contact information for eBay Motors Classified Ad listings. A value of true means seller-level contact information is available for Classified Ad listings. This element is for eBay Motors Pro users.  # noqa: E501

        :return: The ebay_motors_pro_seller_contact_details_enabled of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._ebay_motors_pro_seller_contact_details_enabled

    @ebay_motors_pro_seller_contact_details_enabled.setter
    def ebay_motors_pro_seller_contact_details_enabled(self, ebay_motors_pro_seller_contact_details_enabled):
        """Sets the ebay_motors_pro_seller_contact_details_enabled of this MotorsListingPolicy.

        Indicates whether this category allows seller-level contact information for eBay Motors Classified Ad listings. A value of true means seller-level contact information is available for Classified Ad listings. This element is for eBay Motors Pro users.  # noqa: E501

        :param ebay_motors_pro_seller_contact_details_enabled: The ebay_motors_pro_seller_contact_details_enabled of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._ebay_motors_pro_seller_contact_details_enabled = ebay_motors_pro_seller_contact_details_enabled

    @property
    def ebay_motors_pro_shipping_method_enabled(self):
        """Gets the ebay_motors_pro_shipping_method_enabled of this MotorsListingPolicy.  # noqa: E501

        Indicates if shipping options should be displayed to the user for this category in an eBay Motors Classified Ad listing. This element is for eBay Motors Pro users.  # noqa: E501

        :return: The ebay_motors_pro_shipping_method_enabled of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._ebay_motors_pro_shipping_method_enabled

    @ebay_motors_pro_shipping_method_enabled.setter
    def ebay_motors_pro_shipping_method_enabled(self, ebay_motors_pro_shipping_method_enabled):
        """Sets the ebay_motors_pro_shipping_method_enabled of this MotorsListingPolicy.

        Indicates if shipping options should be displayed to the user for this category in an eBay Motors Classified Ad listing. This element is for eBay Motors Pro users.  # noqa: E501

        :param ebay_motors_pro_shipping_method_enabled: The ebay_motors_pro_shipping_method_enabled of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._ebay_motors_pro_shipping_method_enabled = ebay_motors_pro_shipping_method_enabled

    @property
    def ebay_motors_pro_street_count(self):
        """Gets the ebay_motors_pro_street_count of this MotorsListingPolicy.  # noqa: E501

        This field indicates the number of street addresses allowed in contact information for this category. This element is for eBay Motors Pro users.  # noqa: E501

        :return: The ebay_motors_pro_street_count of this MotorsListingPolicy.  # noqa: E501
        :rtype: int
        """
        return self._ebay_motors_pro_street_count

    @ebay_motors_pro_street_count.setter
    def ebay_motors_pro_street_count(self, ebay_motors_pro_street_count):
        """Sets the ebay_motors_pro_street_count of this MotorsListingPolicy.

        This field indicates the number of street addresses allowed in contact information for this category. This element is for eBay Motors Pro users.  # noqa: E501

        :param ebay_motors_pro_street_count: The ebay_motors_pro_street_count of this MotorsListingPolicy.  # noqa: E501
        :type: int
        """

        self._ebay_motors_pro_street_count = ebay_motors_pro_street_count

    @property
    def epid_supported(self):
        """Gets the epid_supported of this MotorsListingPolicy.  # noqa: E501

        If returned as <code>true</code>, this indicates the category supports the use of an eBay Product ID (e.g. ePID) to identify which motorcycles and/or scooters are compatible with a motor vehicle part or accessory. ePIDs can only be used to identify motorcycles and scooters on the Germany and UK sites.  # noqa: E501

        :return: The epid_supported of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._epid_supported

    @epid_supported.setter
    def epid_supported(self, epid_supported):
        """Sets the epid_supported of this MotorsListingPolicy.

        If returned as <code>true</code>, this indicates the category supports the use of an eBay Product ID (e.g. ePID) to identify which motorcycles and/or scooters are compatible with a motor vehicle part or accessory. ePIDs can only be used to identify motorcycles and scooters on the Germany and UK sites.  # noqa: E501

        :param epid_supported: The epid_supported of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._epid_supported = epid_supported

    @property
    def local_listing_distances(self):
        """Gets the local_listing_distances of this MotorsListingPolicy.  # noqa: E501

        This array shows the supported distances (in miles) for different types of Local Market subscription types in this category. Motor vehicle listings will be shown to buyers located within these proximities of the vehicle's location.  # noqa: E501

        :return: The local_listing_distances of this MotorsListingPolicy.  # noqa: E501
        :rtype: list[LocalListingDistance]
        """
        return self._local_listing_distances

    @local_listing_distances.setter
    def local_listing_distances(self, local_listing_distances):
        """Sets the local_listing_distances of this MotorsListingPolicy.

        This array shows the supported distances (in miles) for different types of Local Market subscription types in this category. Motor vehicle listings will be shown to buyers located within these proximities of the vehicle's location.  # noqa: E501

        :param local_listing_distances: The local_listing_distances of this MotorsListingPolicy.  # noqa: E501
        :type: list[LocalListingDistance]
        """

        self._local_listing_distances = local_listing_distances

    @property
    def local_market_ad_format_enabled(self):
        """Gets the local_market_ad_format_enabled of this MotorsListingPolicy.  # noqa: E501

        Specifies whether this category supports Motor Local Market Classified Ad listings. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:AdFormatEnabledEnum'>eBay API documentation</a>  # noqa: E501

        :return: The local_market_ad_format_enabled of this MotorsListingPolicy.  # noqa: E501
        :rtype: str
        """
        return self._local_market_ad_format_enabled

    @local_market_ad_format_enabled.setter
    def local_market_ad_format_enabled(self, local_market_ad_format_enabled):
        """Sets the local_market_ad_format_enabled of this MotorsListingPolicy.

        Specifies whether this category supports Motor Local Market Classified Ad listings. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:AdFormatEnabledEnum'>eBay API documentation</a>  # noqa: E501

        :param local_market_ad_format_enabled: The local_market_ad_format_enabled of this MotorsListingPolicy.  # noqa: E501
        :type: str
        """

        self._local_market_ad_format_enabled = local_market_ad_format_enabled

    @property
    def local_market_auto_accept_enabled(self):
        """Gets the local_market_auto_accept_enabled of this MotorsListingPolicy.  # noqa: E501

        Specifies whether this category supports auto-accept for Best Offers for Motors Local Market Classified Ads.  # noqa: E501

        :return: The local_market_auto_accept_enabled of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._local_market_auto_accept_enabled

    @local_market_auto_accept_enabled.setter
    def local_market_auto_accept_enabled(self, local_market_auto_accept_enabled):
        """Sets the local_market_auto_accept_enabled of this MotorsListingPolicy.

        Specifies whether this category supports auto-accept for Best Offers for Motors Local Market Classified Ads.  # noqa: E501

        :param local_market_auto_accept_enabled: The local_market_auto_accept_enabled of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._local_market_auto_accept_enabled = local_market_auto_accept_enabled

    @property
    def local_market_auto_decline_enabled(self):
        """Gets the local_market_auto_decline_enabled of this MotorsListingPolicy.  # noqa: E501

        Specifies whether this category supports auto-decline for Best Offers for Motors Local Market Classified Ads.  # noqa: E501

        :return: The local_market_auto_decline_enabled of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._local_market_auto_decline_enabled

    @local_market_auto_decline_enabled.setter
    def local_market_auto_decline_enabled(self, local_market_auto_decline_enabled):
        """Sets the local_market_auto_decline_enabled of this MotorsListingPolicy.

        Specifies whether this category supports auto-decline for Best Offers for Motors Local Market Classified Ads.  # noqa: E501

        :param local_market_auto_decline_enabled: The local_market_auto_decline_enabled of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._local_market_auto_decline_enabled = local_market_auto_decline_enabled

    @property
    def local_market_best_offer_enabled(self):
        """Gets the local_market_best_offer_enabled of this MotorsListingPolicy.  # noqa: E501

        Indicates if Best Offer is enabled/required for Motors Local Market Classified Ad listings in this category.  For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:ClassifiedAdBestOfferEnabledEnum'>eBay API documentation</a>  # noqa: E501

        :return: The local_market_best_offer_enabled of this MotorsListingPolicy.  # noqa: E501
        :rtype: str
        """
        return self._local_market_best_offer_enabled

    @local_market_best_offer_enabled.setter
    def local_market_best_offer_enabled(self, local_market_best_offer_enabled):
        """Sets the local_market_best_offer_enabled of this MotorsListingPolicy.

        Indicates if Best Offer is enabled/required for Motors Local Market Classified Ad listings in this category.  For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:ClassifiedAdBestOfferEnabledEnum'>eBay API documentation</a>  # noqa: E501

        :param local_market_best_offer_enabled: The local_market_best_offer_enabled of this MotorsListingPolicy.  # noqa: E501
        :type: str
        """

        self._local_market_best_offer_enabled = local_market_best_offer_enabled

    @property
    def local_market_company_name_enabled(self):
        """Gets the local_market_company_name_enabled of this MotorsListingPolicy.  # noqa: E501

        Indicates whether the category supports the seller's company name being specified when using Motors Local Market classified ads.  # noqa: E501

        :return: The local_market_company_name_enabled of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._local_market_company_name_enabled

    @local_market_company_name_enabled.setter
    def local_market_company_name_enabled(self, local_market_company_name_enabled):
        """Sets the local_market_company_name_enabled of this MotorsListingPolicy.

        Indicates whether the category supports the seller's company name being specified when using Motors Local Market classified ads.  # noqa: E501

        :param local_market_company_name_enabled: The local_market_company_name_enabled of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._local_market_company_name_enabled = local_market_company_name_enabled

    @property
    def local_market_contact_by_address_enabled(self):
        """Gets the local_market_contact_by_address_enabled of this MotorsListingPolicy.  # noqa: E501

        Indicates whether this category supports including the address in the seller's contact information.  # noqa: E501

        :return: The local_market_contact_by_address_enabled of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._local_market_contact_by_address_enabled

    @local_market_contact_by_address_enabled.setter
    def local_market_contact_by_address_enabled(self, local_market_contact_by_address_enabled):
        """Sets the local_market_contact_by_address_enabled of this MotorsListingPolicy.

        Indicates whether this category supports including the address in the seller's contact information.  # noqa: E501

        :param local_market_contact_by_address_enabled: The local_market_contact_by_address_enabled of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._local_market_contact_by_address_enabled = local_market_contact_by_address_enabled

    @property
    def local_market_contact_by_email_enabled(self):
        """Gets the local_market_contact_by_email_enabled of this MotorsListingPolicy.  # noqa: E501

        Indicates whether the category supports including an email address in the seller's contact information.   # noqa: E501

        :return: The local_market_contact_by_email_enabled of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._local_market_contact_by_email_enabled

    @local_market_contact_by_email_enabled.setter
    def local_market_contact_by_email_enabled(self, local_market_contact_by_email_enabled):
        """Sets the local_market_contact_by_email_enabled of this MotorsListingPolicy.

        Indicates whether the category supports including an email address in the seller's contact information.   # noqa: E501

        :param local_market_contact_by_email_enabled: The local_market_contact_by_email_enabled of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._local_market_contact_by_email_enabled = local_market_contact_by_email_enabled

    @property
    def local_market_contact_by_phone_enabled(self):
        """Gets the local_market_contact_by_phone_enabled of this MotorsListingPolicy.  # noqa: E501

        Indicates whether this category supports including the telephone in the seller's contact information.  # noqa: E501

        :return: The local_market_contact_by_phone_enabled of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._local_market_contact_by_phone_enabled

    @local_market_contact_by_phone_enabled.setter
    def local_market_contact_by_phone_enabled(self, local_market_contact_by_phone_enabled):
        """Sets the local_market_contact_by_phone_enabled of this MotorsListingPolicy.

        Indicates whether this category supports including the telephone in the seller's contact information.  # noqa: E501

        :param local_market_contact_by_phone_enabled: The local_market_contact_by_phone_enabled of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._local_market_contact_by_phone_enabled = local_market_contact_by_phone_enabled

    @property
    def local_market_counter_offer_enabled(self):
        """Gets the local_market_counter_offer_enabled of this MotorsListingPolicy.  # noqa: E501

        Indicates whether counter offers are allowed on Best Offers for this category for Motors Local Market Classified Ad listings.  # noqa: E501

        :return: The local_market_counter_offer_enabled of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._local_market_counter_offer_enabled

    @local_market_counter_offer_enabled.setter
    def local_market_counter_offer_enabled(self, local_market_counter_offer_enabled):
        """Sets the local_market_counter_offer_enabled of this MotorsListingPolicy.

        Indicates whether counter offers are allowed on Best Offers for this category for Motors Local Market Classified Ad listings.  # noqa: E501

        :param local_market_counter_offer_enabled: The local_market_counter_offer_enabled of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._local_market_counter_offer_enabled = local_market_counter_offer_enabled

    @property
    def local_market_non_subscription(self):
        """Gets the local_market_non_subscription of this MotorsListingPolicy.  # noqa: E501

        Indicates whether the category supports a seller creating a Motors Local Market listing without a subscription. This feature is only available to licensed vehicle dealers.  # noqa: E501

        :return: The local_market_non_subscription of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._local_market_non_subscription

    @local_market_non_subscription.setter
    def local_market_non_subscription(self, local_market_non_subscription):
        """Sets the local_market_non_subscription of this MotorsListingPolicy.

        Indicates whether the category supports a seller creating a Motors Local Market listing without a subscription. This feature is only available to licensed vehicle dealers.  # noqa: E501

        :param local_market_non_subscription: The local_market_non_subscription of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._local_market_non_subscription = local_market_non_subscription

    @property
    def local_market_payment_method_check_out_enabled(self):
        """Gets the local_market_payment_method_check_out_enabled of this MotorsListingPolicy.  # noqa: E501

        Indicates if the payment method should be displayed to the user for this category in an Motors Local Market Classified Ad listing. Even if enabled, checkout may or may not be enabled. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:ClassifiedAdPaymentMethodEnabledEnum'>eBay API documentation</a>  # noqa: E501

        :return: The local_market_payment_method_check_out_enabled of this MotorsListingPolicy.  # noqa: E501
        :rtype: str
        """
        return self._local_market_payment_method_check_out_enabled

    @local_market_payment_method_check_out_enabled.setter
    def local_market_payment_method_check_out_enabled(self, local_market_payment_method_check_out_enabled):
        """Sets the local_market_payment_method_check_out_enabled of this MotorsListingPolicy.

        Indicates if the payment method should be displayed to the user for this category in an Motors Local Market Classified Ad listing. Even if enabled, checkout may or may not be enabled. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:ClassifiedAdPaymentMethodEnabledEnum'>eBay API documentation</a>  # noqa: E501

        :param local_market_payment_method_check_out_enabled: The local_market_payment_method_check_out_enabled of this MotorsListingPolicy.  # noqa: E501
        :type: str
        """

        self._local_market_payment_method_check_out_enabled = local_market_payment_method_check_out_enabled

    @property
    def local_market_phone_count(self):
        """Gets the local_market_phone_count of this MotorsListingPolicy.  # noqa: E501

        Indicates the number of phone numbers that can be included through contact information for this category.  # noqa: E501

        :return: The local_market_phone_count of this MotorsListingPolicy.  # noqa: E501
        :rtype: int
        """
        return self._local_market_phone_count

    @local_market_phone_count.setter
    def local_market_phone_count(self, local_market_phone_count):
        """Sets the local_market_phone_count of this MotorsListingPolicy.

        Indicates the number of phone numbers that can be included through contact information for this category.  # noqa: E501

        :param local_market_phone_count: The local_market_phone_count of this MotorsListingPolicy.  # noqa: E501
        :type: int
        """

        self._local_market_phone_count = local_market_phone_count

    @property
    def local_market_premium_subscription(self):
        """Gets the local_market_premium_subscription of this MotorsListingPolicy.  # noqa: E501

        Indicates whether the category supports the Premium level subscription Motors Local Market listings. This feature is only available to licensed vehicle dealers.  # noqa: E501

        :return: The local_market_premium_subscription of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._local_market_premium_subscription

    @local_market_premium_subscription.setter
    def local_market_premium_subscription(self, local_market_premium_subscription):
        """Sets the local_market_premium_subscription of this MotorsListingPolicy.

        Indicates whether the category supports the Premium level subscription Motors Local Market listings. This feature is only available to licensed vehicle dealers.  # noqa: E501

        :param local_market_premium_subscription: The local_market_premium_subscription of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._local_market_premium_subscription = local_market_premium_subscription

    @property
    def local_market_regular_subscription(self):
        """Gets the local_market_regular_subscription of this MotorsListingPolicy.  # noqa: E501

        Indicates whether the category supports the Regular level subscription to Motors Local Market listings. This feature is only available to licensed vehicle dealers.  # noqa: E501

        :return: The local_market_regular_subscription of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._local_market_regular_subscription

    @local_market_regular_subscription.setter
    def local_market_regular_subscription(self, local_market_regular_subscription):
        """Sets the local_market_regular_subscription of this MotorsListingPolicy.

        Indicates whether the category supports the Regular level subscription to Motors Local Market listings. This feature is only available to licensed vehicle dealers.  # noqa: E501

        :param local_market_regular_subscription: The local_market_regular_subscription of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._local_market_regular_subscription = local_market_regular_subscription

    @property
    def local_market_seller_contact_details_enabled(self):
        """Gets the local_market_seller_contact_details_enabled of this MotorsListingPolicy.  # noqa: E501

        Specifies the whether this category allows seller-level contact information for Motors Local Market Classified Ad listings.  # noqa: E501

        :return: The local_market_seller_contact_details_enabled of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._local_market_seller_contact_details_enabled

    @local_market_seller_contact_details_enabled.setter
    def local_market_seller_contact_details_enabled(self, local_market_seller_contact_details_enabled):
        """Sets the local_market_seller_contact_details_enabled of this MotorsListingPolicy.

        Specifies the whether this category allows seller-level contact information for Motors Local Market Classified Ad listings.  # noqa: E501

        :param local_market_seller_contact_details_enabled: The local_market_seller_contact_details_enabled of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._local_market_seller_contact_details_enabled = local_market_seller_contact_details_enabled

    @property
    def local_market_shipping_method_enabled(self):
        """Gets the local_market_shipping_method_enabled of this MotorsListingPolicy.  # noqa: E501

        Indicates if shipping methods should be displayed to the user for this category in an Motors Local Market Classified Ad listing. Even if enabled, checkout may or may not be enabled.  # noqa: E501

        :return: The local_market_shipping_method_enabled of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._local_market_shipping_method_enabled

    @local_market_shipping_method_enabled.setter
    def local_market_shipping_method_enabled(self, local_market_shipping_method_enabled):
        """Sets the local_market_shipping_method_enabled of this MotorsListingPolicy.

        Indicates if shipping methods should be displayed to the user for this category in an Motors Local Market Classified Ad listing. Even if enabled, checkout may or may not be enabled.  # noqa: E501

        :param local_market_shipping_method_enabled: The local_market_shipping_method_enabled of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._local_market_shipping_method_enabled = local_market_shipping_method_enabled

    @property
    def local_market_speciality_subscription(self):
        """Gets the local_market_speciality_subscription of this MotorsListingPolicy.  # noqa: E501

        Indicates whether the category supports the Speciality level subscription to Motors Local Market listings. This feature is only available to licensed vehicle dealers.  # noqa: E501

        :return: The local_market_speciality_subscription of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._local_market_speciality_subscription

    @local_market_speciality_subscription.setter
    def local_market_speciality_subscription(self, local_market_speciality_subscription):
        """Sets the local_market_speciality_subscription of this MotorsListingPolicy.

        Indicates whether the category supports the Speciality level subscription to Motors Local Market listings. This feature is only available to licensed vehicle dealers.  # noqa: E501

        :param local_market_speciality_subscription: The local_market_speciality_subscription of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._local_market_speciality_subscription = local_market_speciality_subscription

    @property
    def local_market_street_count(self):
        """Gets the local_market_street_count of this MotorsListingPolicy.  # noqa: E501

        Indicates which address option is enabled for the seller's contact information.  # noqa: E501

        :return: The local_market_street_count of this MotorsListingPolicy.  # noqa: E501
        :rtype: int
        """
        return self._local_market_street_count

    @local_market_street_count.setter
    def local_market_street_count(self, local_market_street_count):
        """Sets the local_market_street_count of this MotorsListingPolicy.

        Indicates which address option is enabled for the seller's contact information.  # noqa: E501

        :param local_market_street_count: The local_market_street_count of this MotorsListingPolicy.  # noqa: E501
        :type: int
        """

        self._local_market_street_count = local_market_street_count

    @property
    def max_granular_fitment_count(self):
        """Gets the max_granular_fitment_count of this MotorsListingPolicy.  # noqa: E501

        Indicates the maximum number of compatible applications allowed per item when adding or revising items with compatibilities provided at the most detailed granularity. For example, in Car and Truck Parts on the US site, the most granular application would include Year, Make, Model, Trim, and Engine.  # noqa: E501

        :return: The max_granular_fitment_count of this MotorsListingPolicy.  # noqa: E501
        :rtype: int
        """
        return self._max_granular_fitment_count

    @max_granular_fitment_count.setter
    def max_granular_fitment_count(self, max_granular_fitment_count):
        """Sets the max_granular_fitment_count of this MotorsListingPolicy.

        Indicates the maximum number of compatible applications allowed per item when adding or revising items with compatibilities provided at the most detailed granularity. For example, in Car and Truck Parts on the US site, the most granular application would include Year, Make, Model, Trim, and Engine.  # noqa: E501

        :param max_granular_fitment_count: The max_granular_fitment_count of this MotorsListingPolicy.  # noqa: E501
        :type: int
        """

        self._max_granular_fitment_count = max_granular_fitment_count

    @property
    def max_item_compatibility(self):
        """Gets the max_item_compatibility of this MotorsListingPolicy.  # noqa: E501

        specifies the maximum number of compatible applications allowed per item when adding or revising items. This is relevant for specifying parts compatibility by application manually ( Item.ItemCompatibilityList) only.  # noqa: E501

        :return: The max_item_compatibility of this MotorsListingPolicy.  # noqa: E501
        :rtype: int
        """
        return self._max_item_compatibility

    @max_item_compatibility.setter
    def max_item_compatibility(self, max_item_compatibility):
        """Sets the max_item_compatibility of this MotorsListingPolicy.

        specifies the maximum number of compatible applications allowed per item when adding or revising items. This is relevant for specifying parts compatibility by application manually ( Item.ItemCompatibilityList) only.  # noqa: E501

        :param max_item_compatibility: The max_item_compatibility of this MotorsListingPolicy.  # noqa: E501
        :type: int
        """

        self._max_item_compatibility = max_item_compatibility

    @property
    def non_subscription(self):
        """Gets the non_subscription of this MotorsListingPolicy.  # noqa: E501

        The value in this field indicates whether the category supports Motors Local Market listings if the seller does not have a vehicle subscription. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:GeographicExposureEnum'>eBay API documentation</a>  # noqa: E501

        :return: The non_subscription of this MotorsListingPolicy.  # noqa: E501
        :rtype: str
        """
        return self._non_subscription

    @non_subscription.setter
    def non_subscription(self, non_subscription):
        """Sets the non_subscription of this MotorsListingPolicy.

        The value in this field indicates whether the category supports Motors Local Market listings if the seller does not have a vehicle subscription. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:GeographicExposureEnum'>eBay API documentation</a>  # noqa: E501

        :param non_subscription: The non_subscription of this MotorsListingPolicy.  # noqa: E501
        :type: str
        """

        self._non_subscription = non_subscription

    @property
    def premium_subscription(self):
        """Gets the premium_subscription of this MotorsListingPolicy.  # noqa: E501

        The value in this field indicates whether the category supports Motors Local Market listings if the seller has a Premium vehicle subscription. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:GeographicExposureEnum'>eBay API documentation</a>  # noqa: E501

        :return: The premium_subscription of this MotorsListingPolicy.  # noqa: E501
        :rtype: str
        """
        return self._premium_subscription

    @premium_subscription.setter
    def premium_subscription(self, premium_subscription):
        """Sets the premium_subscription of this MotorsListingPolicy.

        The value in this field indicates whether the category supports Motors Local Market listings if the seller has a Premium vehicle subscription. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:GeographicExposureEnum'>eBay API documentation</a>  # noqa: E501

        :param premium_subscription: The premium_subscription of this MotorsListingPolicy.  # noqa: E501
        :type: str
        """

        self._premium_subscription = premium_subscription

    @property
    def regular_subscription(self):
        """Gets the regular_subscription of this MotorsListingPolicy.  # noqa: E501

        The value in this field indicates whether the category supports Motors Local Market listings if the seller has a Regular vehicle subscription. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:GeographicExposureEnum'>eBay API documentation</a>  # noqa: E501

        :return: The regular_subscription of this MotorsListingPolicy.  # noqa: E501
        :rtype: str
        """
        return self._regular_subscription

    @regular_subscription.setter
    def regular_subscription(self, regular_subscription):
        """Sets the regular_subscription of this MotorsListingPolicy.

        The value in this field indicates whether the category supports Motors Local Market listings if the seller has a Regular vehicle subscription. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:GeographicExposureEnum'>eBay API documentation</a>  # noqa: E501

        :param regular_subscription: The regular_subscription of this MotorsListingPolicy.  # noqa: E501
        :type: str
        """

        self._regular_subscription = regular_subscription

    @property
    def seller_provided_title_supported(self):
        """Gets the seller_provided_title_supported of this MotorsListingPolicy.  # noqa: E501

        This field is returned as <code>true</code> if the corresponding category supports the use of a seller-provided title for a motor vehicle listing on the US or Canada Motors marketplaces. A seller-provided title is a descriptive title, given by the seller, that appears below eBay's pre-filled listing title for the motor vehicle. Visually, the seller-provided title is similar to a subtitle on other types of eBay listings (non-vehicle). A seller-provided title can assist in helping buyers discover the vehicle.  # noqa: E501

        :return: The seller_provided_title_supported of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._seller_provided_title_supported

    @seller_provided_title_supported.setter
    def seller_provided_title_supported(self, seller_provided_title_supported):
        """Sets the seller_provided_title_supported of this MotorsListingPolicy.

        This field is returned as <code>true</code> if the corresponding category supports the use of a seller-provided title for a motor vehicle listing on the US or Canada Motors marketplaces. A seller-provided title is a descriptive title, given by the seller, that appears below eBay's pre-filled listing title for the motor vehicle. Visually, the seller-provided title is similar to a subtitle on other types of eBay listings (non-vehicle). A seller-provided title can assist in helping buyers discover the vehicle.  # noqa: E501

        :param seller_provided_title_supported: The seller_provided_title_supported of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._seller_provided_title_supported = seller_provided_title_supported

    @property
    def speciality_subscription(self):
        """Gets the speciality_subscription of this MotorsListingPolicy.  # noqa: E501

        The value in this field indicates whether the category supports Motors Local Market listings if the seller has a Specialty vehicle subscription. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:GeographicExposureEnum'>eBay API documentation</a>  # noqa: E501

        :return: The speciality_subscription of this MotorsListingPolicy.  # noqa: E501
        :rtype: str
        """
        return self._speciality_subscription

    @speciality_subscription.setter
    def speciality_subscription(self, speciality_subscription):
        """Sets the speciality_subscription of this MotorsListingPolicy.

        The value in this field indicates whether the category supports Motors Local Market listings if the seller has a Specialty vehicle subscription. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:GeographicExposureEnum'>eBay API documentation</a>  # noqa: E501

        :param speciality_subscription: The speciality_subscription of this MotorsListingPolicy.  # noqa: E501
        :type: str
        """

        self._speciality_subscription = speciality_subscription

    @property
    def vin_supported(self):
        """Gets the vin_supported of this MotorsListingPolicy.  # noqa: E501

        Indicates if Vehicle Identification Number is supported.  # noqa: E501

        :return: The vin_supported of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._vin_supported

    @vin_supported.setter
    def vin_supported(self, vin_supported):
        """Sets the vin_supported of this MotorsListingPolicy.

        Indicates if Vehicle Identification Number is supported.  # noqa: E501

        :param vin_supported: The vin_supported of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._vin_supported = vin_supported

    @property
    def vrm_supported(self):
        """Gets the vrm_supported of this MotorsListingPolicy.  # noqa: E501

        Indicates if Vehicle Registration Mark is supported.  # noqa: E501

        :return: The vrm_supported of this MotorsListingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._vrm_supported

    @vrm_supported.setter
    def vrm_supported(self, vrm_supported):
        """Sets the vrm_supported of this MotorsListingPolicy.

        Indicates if Vehicle Registration Mark is supported.  # noqa: E501

        :param vrm_supported: The vrm_supported of this MotorsListingPolicy.  # noqa: E501
        :type: bool
        """

        self._vrm_supported = vrm_supported

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MotorsListingPolicy, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MotorsListingPolicy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    EDIS public shipping API

    <div class=\"msgbox_important\"><p class=\"msgbox_importantInDiv\" data-mc-autonum=\"&lt;b&gt;&lt;span style=&quot;color: #dd1e31;&quot; class=&quot;mcFormatColor&quot;&gt;Important! &lt;/span&gt;&lt;/b&gt;\"><span class=\"autonumber\"><span><b><span style=\"color: #dd1e31;\" class=\"mcFormatColor\">Important!</span></b></span></span> This method is only available for Greater-China based sellers with an active eDIS account.</p></div><br>This API allows 3rd party developers in the Greater-China area to process package shipping details.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AddComplaintRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'complaint_request': 'AddComplaintRequestData'
    }

    attribute_map = {
        'complaint_request': 'complaintRequest'
    }

    def __init__(self, complaint_request=None):  # noqa: E501
        """AddComplaintRequest - a model defined in Swagger"""  # noqa: E501
        self._complaint_request = None
        self.discriminator = None
        if complaint_request is not None:
            self.complaint_request = complaint_request

    @property
    def complaint_request(self):
        """Gets the complaint_request of this AddComplaintRequest.  # noqa: E501


        :return: The complaint_request of this AddComplaintRequest.  # noqa: E501
        :rtype: AddComplaintRequestData
        """
        return self._complaint_request

    @complaint_request.setter
    def complaint_request(self, complaint_request):
        """Sets the complaint_request of this AddComplaintRequest.


        :param complaint_request: The complaint_request of this AddComplaintRequest.  # noqa: E501
        :type: AddComplaintRequestData
        """

        self._complaint_request = complaint_request

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddComplaintRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddComplaintRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Translation API

    This API allows 3rd party developers to translate item titles.  # noqa: E501

    OpenAPI spec version: v1_beta.1.6
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Translation(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'original_text': 'str',
        'translated_text': 'str'
    }

    attribute_map = {
        'original_text': 'originalText',
        'translated_text': 'translatedText'
    }

    def __init__(self, original_text=None, translated_text=None):  # noqa: E501
        """Translation - a model defined in Swagger"""  # noqa: E501
        self._original_text = None
        self._translated_text = None
        self.discriminator = None
        if original_text is not None:
            self.original_text = original_text
        if translated_text is not None:
            self.translated_text = translated_text

    @property
    def original_text(self):
        """Gets the original_text of this Translation.  # noqa: E501

        The original text, in the language specified in the <b>from</b> field, that was input into the <b>text</b> field in the request.  # noqa: E501

        :return: The original_text of this Translation.  # noqa: E501
        :rtype: str
        """
        return self._original_text

    @original_text.setter
    def original_text(self, original_text):
        """Sets the original_text of this Translation.

        The original text, in the language specified in the <b>from</b> field, that was input into the <b>text</b> field in the request.  # noqa: E501

        :param original_text: The original_text of this Translation.  # noqa: E501
        :type: str
        """

        self._original_text = original_text

    @property
    def translated_text(self):
        """Gets the translated_text of this Translation.  # noqa: E501

        The translation of the original text into the language specified in the <b>to</b> field.  # noqa: E501

        :return: The translated_text of this Translation.  # noqa: E501
        :rtype: str
        """
        return self._translated_text

    @translated_text.setter
    def translated_text(self, translated_text):
        """Sets the translated_text of this Translation.

        The translation of the original text into the language specified in the <b>to</b> field.  # noqa: E501

        :param translated_text: The translated_text of this Translation.  # noqa: E501
        :type: str
        """

        self._translated_text = translated_text

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Translation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Translation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Vero Public API's

    The VeRO API has methods that allow owners of an intellectual property to report eBay listings that infringe on their intellectual property rights. It contains methods to report a listing, retrieve supported VeRO reason codes, and retrieve the status of submitted and items.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class VeroReasonCodeDetailResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'vero_reason_codes': 'list[VeroReasonCode]'
    }

    attribute_map = {
        'vero_reason_codes': 'veroReasonCodes'
    }

    def __init__(self, vero_reason_codes=None):  # noqa: E501
        """VeroReasonCodeDetailResponse - a model defined in Swagger"""  # noqa: E501
        self._vero_reason_codes = None
        self.discriminator = None
        if vero_reason_codes is not None:
            self.vero_reason_codes = vero_reason_codes

    @property
    def vero_reason_codes(self):
        """Gets the vero_reason_codes of this VeroReasonCodeDetailResponse.  # noqa: E501

        This array provides a list of VeRO reason codes, as well as the ID and details of each code, based on the input criteria.<br><br>If a <b>X-EBAY-C-MARKETPLACE-ID</b> header is used, only VeRO reason codes for that specific site will be returned. If this header is not included, all reason codes for all sites are returned.    # noqa: E501

        :return: The vero_reason_codes of this VeroReasonCodeDetailResponse.  # noqa: E501
        :rtype: list[VeroReasonCode]
        """
        return self._vero_reason_codes

    @vero_reason_codes.setter
    def vero_reason_codes(self, vero_reason_codes):
        """Sets the vero_reason_codes of this VeroReasonCodeDetailResponse.

        This array provides a list of VeRO reason codes, as well as the ID and details of each code, based on the input criteria.<br><br>If a <b>X-EBAY-C-MARKETPLACE-ID</b> header is used, only VeRO reason codes for that specific site will be returned. If this header is not included, all reason codes for all sites are returned.    # noqa: E501

        :param vero_reason_codes: The vero_reason_codes of this VeroReasonCodeDetailResponse.  # noqa: E501
        :type: list[VeroReasonCode]
        """

        self._vero_reason_codes = vero_reason_codes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(VeroReasonCodeDetailResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VeroReasonCodeDetailResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Metadata API

    The Metadata API has operations that retrieve configuration details pertaining to the different eBay marketplaces. In addition to marketplace information, the API also has operations that get information that helps sellers list items on eBay.  # noqa: E501

    OpenAPI spec version: v1.10.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ShippingPolicy(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'category_id': 'str',
        'category_tree_id': 'str',
        'global_shipping_enabled': 'bool',
        'group1_max_flat_shipping_cost': 'Amount',
        'group2_max_flat_shipping_cost': 'Amount',
        'group3_max_flat_shipping_cost': 'Amount',
        'handling_time_enabled': 'bool',
        'max_flat_shipping_cost': 'Amount',
        'shipping_terms_required': 'bool'
    }

    attribute_map = {
        'category_id': 'categoryId',
        'category_tree_id': 'categoryTreeId',
        'global_shipping_enabled': 'globalShippingEnabled',
        'group1_max_flat_shipping_cost': 'group1MaxFlatShippingCost',
        'group2_max_flat_shipping_cost': 'group2MaxFlatShippingCost',
        'group3_max_flat_shipping_cost': 'group3MaxFlatShippingCost',
        'handling_time_enabled': 'handlingTimeEnabled',
        'max_flat_shipping_cost': 'maxFlatShippingCost',
        'shipping_terms_required': 'shippingTermsRequired'
    }

    def __init__(self, category_id=None, category_tree_id=None, global_shipping_enabled=None, group1_max_flat_shipping_cost=None, group2_max_flat_shipping_cost=None, group3_max_flat_shipping_cost=None, handling_time_enabled=None, max_flat_shipping_cost=None, shipping_terms_required=None):  # noqa: E501
        """ShippingPolicy - a model defined in Swagger"""  # noqa: E501
        self._category_id = None
        self._category_tree_id = None
        self._global_shipping_enabled = None
        self._group1_max_flat_shipping_cost = None
        self._group2_max_flat_shipping_cost = None
        self._group3_max_flat_shipping_cost = None
        self._handling_time_enabled = None
        self._max_flat_shipping_cost = None
        self._shipping_terms_required = None
        self.discriminator = None
        if category_id is not None:
            self.category_id = category_id
        if category_tree_id is not None:
            self.category_tree_id = category_tree_id
        if global_shipping_enabled is not None:
            self.global_shipping_enabled = global_shipping_enabled
        if group1_max_flat_shipping_cost is not None:
            self.group1_max_flat_shipping_cost = group1_max_flat_shipping_cost
        if group2_max_flat_shipping_cost is not None:
            self.group2_max_flat_shipping_cost = group2_max_flat_shipping_cost
        if group3_max_flat_shipping_cost is not None:
            self.group3_max_flat_shipping_cost = group3_max_flat_shipping_cost
        if handling_time_enabled is not None:
            self.handling_time_enabled = handling_time_enabled
        if max_flat_shipping_cost is not None:
            self.max_flat_shipping_cost = max_flat_shipping_cost
        if shipping_terms_required is not None:
            self.shipping_terms_required = shipping_terms_required

    @property
    def category_id(self):
        """Gets the category_id of this ShippingPolicy.  # noqa: E501

        The unique identifier of the eBay leaf category for which metadata is being returned.  # noqa: E501

        :return: The category_id of this ShippingPolicy.  # noqa: E501
        :rtype: str
        """
        return self._category_id

    @category_id.setter
    def category_id(self, category_id):
        """Sets the category_id of this ShippingPolicy.

        The unique identifier of the eBay leaf category for which metadata is being returned.  # noqa: E501

        :param category_id: The category_id of this ShippingPolicy.  # noqa: E501
        :type: str
        """

        self._category_id = category_id

    @property
    def category_tree_id(self):
        """Gets the category_tree_id of this ShippingPolicy.  # noqa: E501

        The unique identifier of the category tree.  # noqa: E501

        :return: The category_tree_id of this ShippingPolicy.  # noqa: E501
        :rtype: str
        """
        return self._category_tree_id

    @category_tree_id.setter
    def category_tree_id(self, category_tree_id):
        """Sets the category_tree_id of this ShippingPolicy.

        The unique identifier of the category tree.  # noqa: E501

        :param category_tree_id: The category_tree_id of this ShippingPolicy.  # noqa: E501
        :type: str
        """

        self._category_tree_id = category_tree_id

    @property
    def global_shipping_enabled(self):
        """Gets the global_shipping_enabled of this ShippingPolicy.  # noqa: E501

        Indicates if the Global Shipping Program (GSP) is supported for the category. <p><span class=\"tablenote\"><span style=\"color:#004680\"><strong>Note: </strong>GSP is only supported by the eBay UK marketplace (<code>EBAY_GB</code>).</span></p>  # noqa: E501

        :return: The global_shipping_enabled of this ShippingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._global_shipping_enabled

    @global_shipping_enabled.setter
    def global_shipping_enabled(self, global_shipping_enabled):
        """Sets the global_shipping_enabled of this ShippingPolicy.

        Indicates if the Global Shipping Program (GSP) is supported for the category. <p><span class=\"tablenote\"><span style=\"color:#004680\"><strong>Note: </strong>GSP is only supported by the eBay UK marketplace (<code>EBAY_GB</code>).</span></p>  # noqa: E501

        :param global_shipping_enabled: The global_shipping_enabled of this ShippingPolicy.  # noqa: E501
        :type: bool
        """

        self._global_shipping_enabled = global_shipping_enabled

    @property
    def group1_max_flat_shipping_cost(self):
        """Gets the group1_max_flat_shipping_cost of this ShippingPolicy.  # noqa: E501


        :return: The group1_max_flat_shipping_cost of this ShippingPolicy.  # noqa: E501
        :rtype: Amount
        """
        return self._group1_max_flat_shipping_cost

    @group1_max_flat_shipping_cost.setter
    def group1_max_flat_shipping_cost(self, group1_max_flat_shipping_cost):
        """Sets the group1_max_flat_shipping_cost of this ShippingPolicy.


        :param group1_max_flat_shipping_cost: The group1_max_flat_shipping_cost of this ShippingPolicy.  # noqa: E501
        :type: Amount
        """

        self._group1_max_flat_shipping_cost = group1_max_flat_shipping_cost

    @property
    def group2_max_flat_shipping_cost(self):
        """Gets the group2_max_flat_shipping_cost of this ShippingPolicy.  # noqa: E501


        :return: The group2_max_flat_shipping_cost of this ShippingPolicy.  # noqa: E501
        :rtype: Amount
        """
        return self._group2_max_flat_shipping_cost

    @group2_max_flat_shipping_cost.setter
    def group2_max_flat_shipping_cost(self, group2_max_flat_shipping_cost):
        """Sets the group2_max_flat_shipping_cost of this ShippingPolicy.


        :param group2_max_flat_shipping_cost: The group2_max_flat_shipping_cost of this ShippingPolicy.  # noqa: E501
        :type: Amount
        """

        self._group2_max_flat_shipping_cost = group2_max_flat_shipping_cost

    @property
    def group3_max_flat_shipping_cost(self):
        """Gets the group3_max_flat_shipping_cost of this ShippingPolicy.  # noqa: E501


        :return: The group3_max_flat_shipping_cost of this ShippingPolicy.  # noqa: E501
        :rtype: Amount
        """
        return self._group3_max_flat_shipping_cost

    @group3_max_flat_shipping_cost.setter
    def group3_max_flat_shipping_cost(self, group3_max_flat_shipping_cost):
        """Sets the group3_max_flat_shipping_cost of this ShippingPolicy.


        :param group3_max_flat_shipping_cost: The group3_max_flat_shipping_cost of this ShippingPolicy.  # noqa: E501
        :type: Amount
        """

        self._group3_max_flat_shipping_cost = group3_max_flat_shipping_cost

    @property
    def handling_time_enabled(self):
        """Gets the handling_time_enabled of this ShippingPolicy.  # noqa: E501

        Indicates if a seller's stated handling time is enabled for a category. A handling time is generally needed for items that are shipped to the buyer, but not necessarily applicable to freight shipping or local pickup.  # noqa: E501

        :return: The handling_time_enabled of this ShippingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._handling_time_enabled

    @handling_time_enabled.setter
    def handling_time_enabled(self, handling_time_enabled):
        """Sets the handling_time_enabled of this ShippingPolicy.

        Indicates if a seller's stated handling time is enabled for a category. A handling time is generally needed for items that are shipped to the buyer, but not necessarily applicable to freight shipping or local pickup.  # noqa: E501

        :param handling_time_enabled: The handling_time_enabled of this ShippingPolicy.  # noqa: E501
        :type: bool
        """

        self._handling_time_enabled = handling_time_enabled

    @property
    def max_flat_shipping_cost(self):
        """Gets the max_flat_shipping_cost of this ShippingPolicy.  # noqa: E501


        :return: The max_flat_shipping_cost of this ShippingPolicy.  # noqa: E501
        :rtype: Amount
        """
        return self._max_flat_shipping_cost

    @max_flat_shipping_cost.setter
    def max_flat_shipping_cost(self, max_flat_shipping_cost):
        """Sets the max_flat_shipping_cost of this ShippingPolicy.


        :param max_flat_shipping_cost: The max_flat_shipping_cost of this ShippingPolicy.  # noqa: E501
        :type: Amount
        """

        self._max_flat_shipping_cost = max_flat_shipping_cost

    @property
    def shipping_terms_required(self):
        """Gets the shipping_terms_required of this ShippingPolicy.  # noqa: E501

        Indicates whether the category requires sellers to specify shipping details at listing time.  # noqa: E501

        :return: The shipping_terms_required of this ShippingPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._shipping_terms_required

    @shipping_terms_required.setter
    def shipping_terms_required(self, shipping_terms_required):
        """Sets the shipping_terms_required of this ShippingPolicy.

        Indicates whether the category requires sellers to specify shipping details at listing time.  # noqa: E501

        :param shipping_terms_required: The shipping_terms_required of this ShippingPolicy.  # noqa: E501
        :type: bool
        """

        self._shipping_terms_required = shipping_terms_required

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ShippingPolicy, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShippingPolicy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Analytics API

    The <i>Analytics API</i> provides data and information about a seller and their eBay business.  <br><br>The resources and methods in this API let sellers review information on their listing performance, metrics on their customer service performance, and details on their eBay seller performance rating.  <br><br>The three resources in the Analytics API provide the following data and information: <ul><li><b>Customer Service Metric</b> &ndash; Returns benchmark data and a metric rating pertaining to a seller's customer service performance as compared to other seller's in the same peer group.</li> <li><b>Traffic Report</b> &ndash; Returns data and information that shows how buyers are engaging with a seller's listings.</li> <li><b>Seller Standards Profile</b> &ndash; Returns information pertaining to a seller's profile rating.</li></ul> Sellers can use the data and information returned by the various Analytics API methods to determine where they can make improvements to increase sales and how they might improve their seller status as viewed by eBay buyers.  <br><br>For details on using this API, see <a href=\"/api-docs/sell/static/performance/analyzing-performance.html\" title=\"Selling Integration Guide\">Analyzing seller performance</a>.  # noqa: E501

    OpenAPI spec version: 1.3.2
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class FindSellerStandardsProfilesResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'standards_profiles': 'list[StandardsProfile]'
    }

    attribute_map = {
        'standards_profiles': 'standardsProfiles'
    }

    def __init__(self, standards_profiles=None):  # noqa: E501
        """FindSellerStandardsProfilesResponse - a model defined in Swagger"""  # noqa: E501
        self._standards_profiles = None
        self.discriminator = None
        if standards_profiles is not None:
            self.standards_profiles = standards_profiles

    @property
    def standards_profiles(self):
        """Gets the standards_profiles of this FindSellerStandardsProfilesResponse.  # noqa: E501

        A list of the seller's standards profiles.  <br><br>A \"standards profile\" is a set of eBay seller standards categories and the values related to the associated seller.  <br><br>Profiles are distinguished by a combination of cycle and program values. The \"program\" value specifies the region to which the data is from. The \"cycle\" value specifies whether the values were determined just now, or if the values are from the last official eBay seller standards evaluation.  # noqa: E501

        :return: The standards_profiles of this FindSellerStandardsProfilesResponse.  # noqa: E501
        :rtype: list[StandardsProfile]
        """
        return self._standards_profiles

    @standards_profiles.setter
    def standards_profiles(self, standards_profiles):
        """Sets the standards_profiles of this FindSellerStandardsProfilesResponse.

        A list of the seller's standards profiles.  <br><br>A \"standards profile\" is a set of eBay seller standards categories and the values related to the associated seller.  <br><br>Profiles are distinguished by a combination of cycle and program values. The \"program\" value specifies the region to which the data is from. The \"cycle\" value specifies whether the values were determined just now, or if the values are from the last official eBay seller standards evaluation.  # noqa: E501

        :param standards_profiles: The standards_profiles of this FindSellerStandardsProfilesResponse.  # noqa: E501
        :type: list[StandardsProfile]
        """

        self._standards_profiles = standards_profiles

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FindSellerStandardsProfilesResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FindSellerStandardsProfilesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    EDIS public shipping API

    <div class=\"msgbox_important\"><p class=\"msgbox_importantInDiv\" data-mc-autonum=\"&lt;b&gt;&lt;span style=&quot;color: #dd1e31;&quot; class=&quot;mcFormatColor&quot;&gt;Important! &lt;/span&gt;&lt;/b&gt;\"><span class=\"autonumber\"><span><b><span style=\"color: #dd1e31;\" class=\"mcFormatColor\">Important!</span></b></span></span> This method is only available for Greater-China based sellers with an active eDIS account.</p></div><br>This API allows 3rd party developers in the Greater-China area to process package shipping details.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PickupAddressRequestData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'city': 'str',
        'company': 'str',
        'contact': 'str',
        'country_code': 'str',
        'district': 'str',
        'name': 'str',
        'phone': 'str',
        'postcode': 'str',
        'province': 'str',
        'street1': 'str',
        'street2': 'str',
        'street3': 'str'
    }

    attribute_map = {
        'city': 'city',
        'company': 'company',
        'contact': 'contact',
        'country_code': 'countryCode',
        'district': 'district',
        'name': 'name',
        'phone': 'phone',
        'postcode': 'postcode',
        'province': 'province',
        'street1': 'street1',
        'street2': 'street2',
        'street3': 'street3'
    }

    def __init__(self, city=None, company=None, contact=None, country_code=None, district=None, name=None, phone=None, postcode=None, province=None, street1=None, street2=None, street3=None):  # noqa: E501
        """PickupAddressRequestData - a model defined in Swagger"""  # noqa: E501
        self._city = None
        self._company = None
        self._contact = None
        self._country_code = None
        self._district = None
        self._name = None
        self._phone = None
        self._postcode = None
        self._province = None
        self._street1 = None
        self._street2 = None
        self._street3 = None
        self.discriminator = None
        if city is not None:
            self.city = city
        if company is not None:
            self.company = company
        if contact is not None:
            self.contact = contact
        if country_code is not None:
            self.country_code = country_code
        if district is not None:
            self.district = district
        if name is not None:
            self.name = name
        if phone is not None:
            self.phone = phone
        if postcode is not None:
            self.postcode = postcode
        if province is not None:
            self.province = province
        if street1 is not None:
            self.street1 = street1
        if street2 is not None:
            self.street2 = street2
        if street3 is not None:
            self.street3 = street3

    @property
    def city(self):
        """Gets the city of this PickupAddressRequestData.  # noqa: E501

        The city code of the pickup address.<br><br>See <a href=\"https://www.edisebay.com/open/development-guide-detail?id=36\" target=\"_blank\">商户API地址编码主数据</a> for valid city codes.  # noqa: E501

        :return: The city of this PickupAddressRequestData.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this PickupAddressRequestData.

        The city code of the pickup address.<br><br>See <a href=\"https://www.edisebay.com/open/development-guide-detail?id=36\" target=\"_blank\">商户API地址编码主数据</a> for valid city codes.  # noqa: E501

        :param city: The city of this PickupAddressRequestData.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def company(self):
        """Gets the company of this PickupAddressRequestData.  # noqa: E501

        The company name associated with the pickup address.<br><br><b>Max length</b>: 50 characters  # noqa: E501

        :return: The company of this PickupAddressRequestData.  # noqa: E501
        :rtype: str
        """
        return self._company

    @company.setter
    def company(self, company):
        """Sets the company of this PickupAddressRequestData.

        The company name associated with the pickup address.<br><br><b>Max length</b>: 50 characters  # noqa: E501

        :param company: The company of this PickupAddressRequestData.  # noqa: E501
        :type: str
        """

        self._company = company

    @property
    def contact(self):
        """Gets the contact of this PickupAddressRequestData.  # noqa: E501

        The name of the contact person associated with the pickup address.<br><br><b>Max length</b>: 50 characters  # noqa: E501

        :return: The contact of this PickupAddressRequestData.  # noqa: E501
        :rtype: str
        """
        return self._contact

    @contact.setter
    def contact(self, contact):
        """Sets the contact of this PickupAddressRequestData.

        The name of the contact person associated with the pickup address.<br><br><b>Max length</b>: 50 characters  # noqa: E501

        :param contact: The contact of this PickupAddressRequestData.  # noqa: E501
        :type: str
        """

        self._contact = contact

    @property
    def country_code(self):
        """Gets the country_code of this PickupAddressRequestData.  # noqa: E501

        The two-letter country code of the pickup address.<br><br><b>Valid values</b>:<ul><li>CN</li><li>HK</li></ul>  # noqa: E501

        :return: The country_code of this PickupAddressRequestData.  # noqa: E501
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """Sets the country_code of this PickupAddressRequestData.

        The two-letter country code of the pickup address.<br><br><b>Valid values</b>:<ul><li>CN</li><li>HK</li></ul>  # noqa: E501

        :param country_code: The country_code of this PickupAddressRequestData.  # noqa: E501
        :type: str
        """

        self._country_code = country_code

    @property
    def district(self):
        """Gets the district of this PickupAddressRequestData.  # noqa: E501

        The district code of the pickup address. <br><br>See <a href=\"https://www.edisebay.com/open/development-guide-detail?id=36\" target=\"_blank\">商户API地址编码主数据</a> for valid district codes.  # noqa: E501

        :return: The district of this PickupAddressRequestData.  # noqa: E501
        :rtype: str
        """
        return self._district

    @district.setter
    def district(self, district):
        """Sets the district of this PickupAddressRequestData.

        The district code of the pickup address. <br><br>See <a href=\"https://www.edisebay.com/open/development-guide-detail?id=36\" target=\"_blank\">商户API地址编码主数据</a> for valid district codes.  # noqa: E501

        :param district: The district of this PickupAddressRequestData.  # noqa: E501
        :type: str
        """

        self._district = district

    @property
    def name(self):
        """Gets the name of this PickupAddressRequestData.  # noqa: E501

        The name of the pickup address.<br><br><b>Max length</b>: 50 characters  # noqa: E501

        :return: The name of this PickupAddressRequestData.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PickupAddressRequestData.

        The name of the pickup address.<br><br><b>Max length</b>: 50 characters  # noqa: E501

        :param name: The name of this PickupAddressRequestData.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def phone(self):
        """Gets the phone of this PickupAddressRequestData.  # noqa: E501

        The phone number associated with the pickup address.  # noqa: E501

        :return: The phone of this PickupAddressRequestData.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this PickupAddressRequestData.

        The phone number associated with the pickup address.  # noqa: E501

        :param phone: The phone of this PickupAddressRequestData.  # noqa: E501
        :type: str
        """

        self._phone = phone

    @property
    def postcode(self):
        """Gets the postcode of this PickupAddressRequestData.  # noqa: E501

        The postal code of the pickup address.  # noqa: E501

        :return: The postcode of this PickupAddressRequestData.  # noqa: E501
        :rtype: str
        """
        return self._postcode

    @postcode.setter
    def postcode(self, postcode):
        """Sets the postcode of this PickupAddressRequestData.

        The postal code of the pickup address.  # noqa: E501

        :param postcode: The postcode of this PickupAddressRequestData.  # noqa: E501
        :type: str
        """

        self._postcode = postcode

    @property
    def province(self):
        """Gets the province of this PickupAddressRequestData.  # noqa: E501

        The province code of the the pickup address.<br><br>See <a href=\"https://www.edisebay.com/open/development-guide-detail?id=36\" target=\"_blank\">商户API地址编码主数据</a> for valid province codes.  # noqa: E501

        :return: The province of this PickupAddressRequestData.  # noqa: E501
        :rtype: str
        """
        return self._province

    @province.setter
    def province(self, province):
        """Sets the province of this PickupAddressRequestData.

        The province code of the the pickup address.<br><br>See <a href=\"https://www.edisebay.com/open/development-guide-detail?id=36\" target=\"_blank\">商户API地址编码主数据</a> for valid province codes.  # noqa: E501

        :param province: The province of this PickupAddressRequestData.  # noqa: E501
        :type: str
        """

        self._province = province

    @property
    def street1(self):
        """Gets the street1 of this PickupAddressRequestData.  # noqa: E501

        The first line of the street address of the pickup address.<br><br><b>Max length</b>: 50 characters  # noqa: E501

        :return: The street1 of this PickupAddressRequestData.  # noqa: E501
        :rtype: str
        """
        return self._street1

    @street1.setter
    def street1(self, street1):
        """Sets the street1 of this PickupAddressRequestData.

        The first line of the street address of the pickup address.<br><br><b>Max length</b>: 50 characters  # noqa: E501

        :param street1: The street1 of this PickupAddressRequestData.  # noqa: E501
        :type: str
        """

        self._street1 = street1

    @property
    def street2(self):
        """Gets the street2 of this PickupAddressRequestData.  # noqa: E501

        The second line, if applicable, of the street address of the pickup address.<br><br><b>Max length</b>: 50 characters  # noqa: E501

        :return: The street2 of this PickupAddressRequestData.  # noqa: E501
        :rtype: str
        """
        return self._street2

    @street2.setter
    def street2(self, street2):
        """Sets the street2 of this PickupAddressRequestData.

        The second line, if applicable, of the street address of the pickup address.<br><br><b>Max length</b>: 50 characters  # noqa: E501

        :param street2: The street2 of this PickupAddressRequestData.  # noqa: E501
        :type: str
        """

        self._street2 = street2

    @property
    def street3(self):
        """Gets the street3 of this PickupAddressRequestData.  # noqa: E501

        The third line, if applicable, of the street address of the pickup address.<br><br><b>Max length</b>: 50 characters  # noqa: E501

        :return: The street3 of this PickupAddressRequestData.  # noqa: E501
        :rtype: str
        """
        return self._street3

    @street3.setter
    def street3(self, street3):
        """Sets the street3 of this PickupAddressRequestData.

        The third line, if applicable, of the street address of the pickup address.<br><br><b>Max length</b>: 50 characters  # noqa: E501

        :param street3: The street3 of this PickupAddressRequestData.  # noqa: E501
        :type: str
        """

        self._street3 = street3

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PickupAddressRequestData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PickupAddressRequestData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    EDIS public shipping API

    <div class=\"msgbox_important\"><p class=\"msgbox_importantInDiv\" data-mc-autonum=\"&lt;b&gt;&lt;span style=&quot;color: #dd1e31;&quot; class=&quot;mcFormatColor&quot;&gt;Important! &lt;/span&gt;&lt;/b&gt;\"><span class=\"autonumber\"><span><b><span style=\"color: #dd1e31;\" class=\"mcFormatColor\">Important!</span></b></span></span> This method is only available for Greater-China based sellers with an active eDIS account.</p></div><br>This API allows 3rd party developers in the Greater-China area to process package shipping details.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ServiceInfoResponses(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description_en': 'str',
        'description_hk': 'str',
        'description_jp': 'str',
        'description_zh': 'str',
        'directions': 'list[DirectionsResponses]',
        'incoterm': 'str',
        'max_length': 'float',
        'max_total_length': 'float',
        'max_weight': 'float',
        'name_en': 'str',
        'name_hk': 'str',
        'name_jp': 'str',
        'name_zh': 'str',
        'shipping_service_id': 'str'
    }

    attribute_map = {
        'description_en': 'descriptionEn',
        'description_hk': 'descriptionHk',
        'description_jp': 'descriptionJp',
        'description_zh': 'descriptionZh',
        'directions': 'directions',
        'incoterm': 'incoterm',
        'max_length': 'maxLength',
        'max_total_length': 'maxTotalLength',
        'max_weight': 'maxWeight',
        'name_en': 'nameEn',
        'name_hk': 'nameHk',
        'name_jp': 'nameJp',
        'name_zh': 'nameZh',
        'shipping_service_id': 'shippingServiceId'
    }

    def __init__(self, description_en=None, description_hk=None, description_jp=None, description_zh=None, directions=None, incoterm=None, max_length=None, max_total_length=None, max_weight=None, name_en=None, name_hk=None, name_jp=None, name_zh=None, shipping_service_id=None):  # noqa: E501
        """ServiceInfoResponses - a model defined in Swagger"""  # noqa: E501
        self._description_en = None
        self._description_hk = None
        self._description_jp = None
        self._description_zh = None
        self._directions = None
        self._incoterm = None
        self._max_length = None
        self._max_total_length = None
        self._max_weight = None
        self._name_en = None
        self._name_hk = None
        self._name_jp = None
        self._name_zh = None
        self._shipping_service_id = None
        self.discriminator = None
        if description_en is not None:
            self.description_en = description_en
        if description_hk is not None:
            self.description_hk = description_hk
        if description_jp is not None:
            self.description_jp = description_jp
        if description_zh is not None:
            self.description_zh = description_zh
        if directions is not None:
            self.directions = directions
        if incoterm is not None:
            self.incoterm = incoterm
        if max_length is not None:
            self.max_length = max_length
        if max_total_length is not None:
            self.max_total_length = max_total_length
        if max_weight is not None:
            self.max_weight = max_weight
        if name_en is not None:
            self.name_en = name_en
        if name_hk is not None:
            self.name_hk = name_hk
        if name_jp is not None:
            self.name_jp = name_jp
        if name_zh is not None:
            self.name_zh = name_zh
        if shipping_service_id is not None:
            self.shipping_service_id = shipping_service_id

    @property
    def description_en(self):
        """Gets the description_en of this ServiceInfoResponses.  # noqa: E501

        Basic shipping service information in English.  # noqa: E501

        :return: The description_en of this ServiceInfoResponses.  # noqa: E501
        :rtype: str
        """
        return self._description_en

    @description_en.setter
    def description_en(self, description_en):
        """Sets the description_en of this ServiceInfoResponses.

        Basic shipping service information in English.  # noqa: E501

        :param description_en: The description_en of this ServiceInfoResponses.  # noqa: E501
        :type: str
        """

        self._description_en = description_en

    @property
    def description_hk(self):
        """Gets the description_hk of this ServiceInfoResponses.  # noqa: E501

        Basic shipping service information in traditional Chinese.  # noqa: E501

        :return: The description_hk of this ServiceInfoResponses.  # noqa: E501
        :rtype: str
        """
        return self._description_hk

    @description_hk.setter
    def description_hk(self, description_hk):
        """Sets the description_hk of this ServiceInfoResponses.

        Basic shipping service information in traditional Chinese.  # noqa: E501

        :param description_hk: The description_hk of this ServiceInfoResponses.  # noqa: E501
        :type: str
        """

        self._description_hk = description_hk

    @property
    def description_jp(self):
        """Gets the description_jp of this ServiceInfoResponses.  # noqa: E501

        Basic shipping service information in Japanese.  # noqa: E501

        :return: The description_jp of this ServiceInfoResponses.  # noqa: E501
        :rtype: str
        """
        return self._description_jp

    @description_jp.setter
    def description_jp(self, description_jp):
        """Sets the description_jp of this ServiceInfoResponses.

        Basic shipping service information in Japanese.  # noqa: E501

        :param description_jp: The description_jp of this ServiceInfoResponses.  # noqa: E501
        :type: str
        """

        self._description_jp = description_jp

    @property
    def description_zh(self):
        """Gets the description_zh of this ServiceInfoResponses.  # noqa: E501

        Basic shipping service information in simplified Chinese.  # noqa: E501

        :return: The description_zh of this ServiceInfoResponses.  # noqa: E501
        :rtype: str
        """
        return self._description_zh

    @description_zh.setter
    def description_zh(self, description_zh):
        """Sets the description_zh of this ServiceInfoResponses.

        Basic shipping service information in simplified Chinese.  # noqa: E501

        :param description_zh: The description_zh of this ServiceInfoResponses.  # noqa: E501
        :type: str
        """

        self._description_zh = description_zh

    @property
    def directions(self):
        """Gets the directions of this ServiceInfoResponses.  # noqa: E501

        This array lists includes all Ship From/Ship To combinations that the service supports. It also includes the type of batteries that may be shipping using the shipping service.  # noqa: E501

        :return: The directions of this ServiceInfoResponses.  # noqa: E501
        :rtype: list[DirectionsResponses]
        """
        return self._directions

    @directions.setter
    def directions(self, directions):
        """Sets the directions of this ServiceInfoResponses.

        This array lists includes all Ship From/Ship To combinations that the service supports. It also includes the type of batteries that may be shipping using the shipping service.  # noqa: E501

        :param directions: The directions of this ServiceInfoResponses.  # noqa: E501
        :type: list[DirectionsResponses]
        """

        self._directions = directions

    @property
    def incoterm(self):
        """Gets the incoterm of this ServiceInfoResponses.  # noqa: E501

        The incoterm information associated with the the shipping service.<br><br><b>Supported values</b>:<ul><li><code>DDP</code></li><li><code>DDU</code></li></ul> For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/edelivery_international_shipping/types/api:IncotermEnum'>eBay API documentation</a>  # noqa: E501

        :return: The incoterm of this ServiceInfoResponses.  # noqa: E501
        :rtype: str
        """
        return self._incoterm

    @incoterm.setter
    def incoterm(self, incoterm):
        """Sets the incoterm of this ServiceInfoResponses.

        The incoterm information associated with the the shipping service.<br><br><b>Supported values</b>:<ul><li><code>DDP</code></li><li><code>DDU</code></li></ul> For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/edelivery_international_shipping/types/api:IncotermEnum'>eBay API documentation</a>  # noqa: E501

        :param incoterm: The incoterm of this ServiceInfoResponses.  # noqa: E501
        :type: str
        """

        self._incoterm = incoterm

    @property
    def max_length(self):
        """Gets the max_length of this ServiceInfoResponses.  # noqa: E501

        This value indicates the maximum length (in centimeters) of the shipping package that the shipping service allows.<br><br><span class=\"tablenote\"><b>Note:</b> This field is always returned, but will show as null or have an empty value if not defined/applicable.</span>  # noqa: E501

        :return: The max_length of this ServiceInfoResponses.  # noqa: E501
        :rtype: float
        """
        return self._max_length

    @max_length.setter
    def max_length(self, max_length):
        """Sets the max_length of this ServiceInfoResponses.

        This value indicates the maximum length (in centimeters) of the shipping package that the shipping service allows.<br><br><span class=\"tablenote\"><b>Note:</b> This field is always returned, but will show as null or have an empty value if not defined/applicable.</span>  # noqa: E501

        :param max_length: The max_length of this ServiceInfoResponses.  # noqa: E501
        :type: float
        """

        self._max_length = max_length

    @property
    def max_total_length(self):
        """Gets the max_total_length of this ServiceInfoResponses.  # noqa: E501

        This value indicates the total maximum value of the length, width, and height of the package.<br><br><span class=\"tablenote\"><b>Note:</b> This field is always returned, but will show as null or have an empty value if not defined/applicable.</span>  # noqa: E501

        :return: The max_total_length of this ServiceInfoResponses.  # noqa: E501
        :rtype: float
        """
        return self._max_total_length

    @max_total_length.setter
    def max_total_length(self, max_total_length):
        """Sets the max_total_length of this ServiceInfoResponses.

        This value indicates the total maximum value of the length, width, and height of the package.<br><br><span class=\"tablenote\"><b>Note:</b> This field is always returned, but will show as null or have an empty value if not defined/applicable.</span>  # noqa: E501

        :param max_total_length: The max_total_length of this ServiceInfoResponses.  # noqa: E501
        :type: float
        """

        self._max_total_length = max_total_length

    @property
    def max_weight(self):
        """Gets the max_weight of this ServiceInfoResponses.  # noqa: E501

        This value indicates the maximum weight (in grams) of the shipping package that the shipping service allows.<br><br><span class=\"tablenote\"><b>Note:</b> This field is always returned, but will show as null or have an empty value if not defined/applicable.</span>  # noqa: E501

        :return: The max_weight of this ServiceInfoResponses.  # noqa: E501
        :rtype: float
        """
        return self._max_weight

    @max_weight.setter
    def max_weight(self, max_weight):
        """Sets the max_weight of this ServiceInfoResponses.

        This value indicates the maximum weight (in grams) of the shipping package that the shipping service allows.<br><br><span class=\"tablenote\"><b>Note:</b> This field is always returned, but will show as null or have an empty value if not defined/applicable.</span>  # noqa: E501

        :param max_weight: The max_weight of this ServiceInfoResponses.  # noqa: E501
        :type: float
        """

        self._max_weight = max_weight

    @property
    def name_en(self):
        """Gets the name_en of this ServiceInfoResponses.  # noqa: E501

        The shipping service name in English  # noqa: E501

        :return: The name_en of this ServiceInfoResponses.  # noqa: E501
        :rtype: str
        """
        return self._name_en

    @name_en.setter
    def name_en(self, name_en):
        """Sets the name_en of this ServiceInfoResponses.

        The shipping service name in English  # noqa: E501

        :param name_en: The name_en of this ServiceInfoResponses.  # noqa: E501
        :type: str
        """

        self._name_en = name_en

    @property
    def name_hk(self):
        """Gets the name_hk of this ServiceInfoResponses.  # noqa: E501

        The shipping service name in traditional Chinese  # noqa: E501

        :return: The name_hk of this ServiceInfoResponses.  # noqa: E501
        :rtype: str
        """
        return self._name_hk

    @name_hk.setter
    def name_hk(self, name_hk):
        """Sets the name_hk of this ServiceInfoResponses.

        The shipping service name in traditional Chinese  # noqa: E501

        :param name_hk: The name_hk of this ServiceInfoResponses.  # noqa: E501
        :type: str
        """

        self._name_hk = name_hk

    @property
    def name_jp(self):
        """Gets the name_jp of this ServiceInfoResponses.  # noqa: E501

        The shipping service name in Japanese.  # noqa: E501

        :return: The name_jp of this ServiceInfoResponses.  # noqa: E501
        :rtype: str
        """
        return self._name_jp

    @name_jp.setter
    def name_jp(self, name_jp):
        """Sets the name_jp of this ServiceInfoResponses.

        The shipping service name in Japanese.  # noqa: E501

        :param name_jp: The name_jp of this ServiceInfoResponses.  # noqa: E501
        :type: str
        """

        self._name_jp = name_jp

    @property
    def name_zh(self):
        """Gets the name_zh of this ServiceInfoResponses.  # noqa: E501

        The shipping service name in simplified Chinese  # noqa: E501

        :return: The name_zh of this ServiceInfoResponses.  # noqa: E501
        :rtype: str
        """
        return self._name_zh

    @name_zh.setter
    def name_zh(self, name_zh):
        """Sets the name_zh of this ServiceInfoResponses.

        The shipping service name in simplified Chinese  # noqa: E501

        :param name_zh: The name_zh of this ServiceInfoResponses.  # noqa: E501
        :type: str
        """

        self._name_zh = name_zh

    @property
    def shipping_service_id(self):
        """Gets the shipping_service_id of this ServiceInfoResponses.  # noqa: E501

        The unique identifier of the shipping service being retrieved.<br><br>This value can be input in the <a href=\"/api-docs/sell/edelivery_international_shipping/resources/package/methods/createPackage#request.packageInfo.shippingServiceId\" target=\"_blank\">shippingServiceId</a> field when creating a package through the the <b>createPackage</b> method.  # noqa: E501

        :return: The shipping_service_id of this ServiceInfoResponses.  # noqa: E501
        :rtype: str
        """
        return self._shipping_service_id

    @shipping_service_id.setter
    def shipping_service_id(self, shipping_service_id):
        """Sets the shipping_service_id of this ServiceInfoResponses.

        The unique identifier of the shipping service being retrieved.<br><br>This value can be input in the <a href=\"/api-docs/sell/edelivery_international_shipping/resources/package/methods/createPackage#request.packageInfo.shippingServiceId\" target=\"_blank\">shippingServiceId</a> field when creating a package through the the <b>createPackage</b> method.  # noqa: E501

        :param shipping_service_id: The shipping_service_id of this ServiceInfoResponses.  # noqa: E501
        :type: str
        """

        self._shipping_service_id = shipping_service_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ServiceInfoResponses, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServiceInfoResponses):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Inventory API

    The Inventory API is used to create and manage inventory, and then to publish and manage this inventory on an eBay marketplace. There are also methods in this API that will convert eligible, active eBay listings into the Inventory API model.  # noqa: E501

    OpenAPI spec version: 1.18.2
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Manufacturer(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'address_line1': 'str',
        'address_line2': 'str',
        'city': 'str',
        'company_name': 'str',
        'contact_url': 'str',
        'country': 'str',
        'email': 'str',
        'phone': 'str',
        'postal_code': 'str',
        'state_or_province': 'str'
    }

    attribute_map = {
        'address_line1': 'addressLine1',
        'address_line2': 'addressLine2',
        'city': 'city',
        'company_name': 'companyName',
        'contact_url': 'contactUrl',
        'country': 'country',
        'email': 'email',
        'phone': 'phone',
        'postal_code': 'postalCode',
        'state_or_province': 'stateOrProvince'
    }

    def __init__(self, address_line1=None, address_line2=None, city=None, company_name=None, contact_url=None, country=None, email=None, phone=None, postal_code=None, state_or_province=None):  # noqa: E501
        """Manufacturer - a model defined in Swagger"""  # noqa: E501
        self._address_line1 = None
        self._address_line2 = None
        self._city = None
        self._company_name = None
        self._contact_url = None
        self._country = None
        self._email = None
        self._phone = None
        self._postal_code = None
        self._state_or_province = None
        self.discriminator = None
        if address_line1 is not None:
            self.address_line1 = address_line1
        if address_line2 is not None:
            self.address_line2 = address_line2
        if city is not None:
            self.city = city
        if company_name is not None:
            self.company_name = company_name
        if contact_url is not None:
            self.contact_url = contact_url
        if country is not None:
            self.country = country
        if email is not None:
            self.email = email
        if phone is not None:
            self.phone = phone
        if postal_code is not None:
            self.postal_code = postal_code
        if state_or_province is not None:
            self.state_or_province = state_or_province

    @property
    def address_line1(self):
        """Gets the address_line1 of this Manufacturer.  # noqa: E501

        The first line of the product manufacturer's street address.<br><br><b>Max length</b>: 180 characters  # noqa: E501

        :return: The address_line1 of this Manufacturer.  # noqa: E501
        :rtype: str
        """
        return self._address_line1

    @address_line1.setter
    def address_line1(self, address_line1):
        """Sets the address_line1 of this Manufacturer.

        The first line of the product manufacturer's street address.<br><br><b>Max length</b>: 180 characters  # noqa: E501

        :param address_line1: The address_line1 of this Manufacturer.  # noqa: E501
        :type: str
        """

        self._address_line1 = address_line1

    @property
    def address_line2(self):
        """Gets the address_line2 of this Manufacturer.  # noqa: E501

        The second line of the product manufacturer's street address. This field is not always used, but can be used for secondary address information such as 'Suite Number' or 'Apt Number'.<br><br><b>Max length</b>: 180 characters  # noqa: E501

        :return: The address_line2 of this Manufacturer.  # noqa: E501
        :rtype: str
        """
        return self._address_line2

    @address_line2.setter
    def address_line2(self, address_line2):
        """Sets the address_line2 of this Manufacturer.

        The second line of the product manufacturer's street address. This field is not always used, but can be used for secondary address information such as 'Suite Number' or 'Apt Number'.<br><br><b>Max length</b>: 180 characters  # noqa: E501

        :param address_line2: The address_line2 of this Manufacturer.  # noqa: E501
        :type: str
        """

        self._address_line2 = address_line2

    @property
    def city(self):
        """Gets the city of this Manufacturer.  # noqa: E501

        The city of the product manufacturer's street address.<br><br><b>Max length</b>: 64 characters  # noqa: E501

        :return: The city of this Manufacturer.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this Manufacturer.

        The city of the product manufacturer's street address.<br><br><b>Max length</b>: 64 characters  # noqa: E501

        :param city: The city of this Manufacturer.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def company_name(self):
        """Gets the company_name of this Manufacturer.  # noqa: E501

        The company name of the product manufacturer.<br><br><b>Max length</b>: 100 characters  # noqa: E501

        :return: The company_name of this Manufacturer.  # noqa: E501
        :rtype: str
        """
        return self._company_name

    @company_name.setter
    def company_name(self, company_name):
        """Sets the company_name of this Manufacturer.

        The company name of the product manufacturer.<br><br><b>Max length</b>: 100 characters  # noqa: E501

        :param company_name: The company_name of this Manufacturer.  # noqa: E501
        :type: str
        """

        self._company_name = company_name

    @property
    def contact_url(self):
        """Gets the contact_url of this Manufacturer.  # noqa: E501

        The contact URL of the product manufacturer.<br><br><b>Max length</b>: 250 characters  # noqa: E501

        :return: The contact_url of this Manufacturer.  # noqa: E501
        :rtype: str
        """
        return self._contact_url

    @contact_url.setter
    def contact_url(self, contact_url):
        """Sets the contact_url of this Manufacturer.

        The contact URL of the product manufacturer.<br><br><b>Max length</b>: 250 characters  # noqa: E501

        :param contact_url: The contact_url of this Manufacturer.  # noqa: E501
        :type: str
        """

        self._contact_url = contact_url

    @property
    def country(self):
        """Gets the country of this Manufacturer.  # noqa: E501

        This defines the list of valid country codes, adapted from http://www.iso.org/iso/country_codes, ISO 3166-1 country code. List elements take the following form to identify a two-letter code with a short name in English, a three-digit code, and a three-letter code: For example, the entry for Japan includes Japan, 392, JPN. Short codes provide uniform recognition, avoiding language-dependent country names. The number code is helpful where Latin script may be problematic. Not all listed codes are universally recognized as countries, for example: code AQ is Antarctica, 010, ATA For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/inventory/types/ba:CountryCodeEnum'>eBay API documentation</a>  # noqa: E501

        :return: The country of this Manufacturer.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this Manufacturer.

        This defines the list of valid country codes, adapted from http://www.iso.org/iso/country_codes, ISO 3166-1 country code. List elements take the following form to identify a two-letter code with a short name in English, a three-digit code, and a three-letter code: For example, the entry for Japan includes Japan, 392, JPN. Short codes provide uniform recognition, avoiding language-dependent country names. The number code is helpful where Latin script may be problematic. Not all listed codes are universally recognized as countries, for example: code AQ is Antarctica, 010, ATA For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/inventory/types/ba:CountryCodeEnum'>eBay API documentation</a>  # noqa: E501

        :param country: The country of this Manufacturer.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def email(self):
        """Gets the email of this Manufacturer.  # noqa: E501

        The product manufacturer's business email address.<br><br><b>Max length</b>: 180 characters  # noqa: E501

        :return: The email of this Manufacturer.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this Manufacturer.

        The product manufacturer's business email address.<br><br><b>Max length</b>: 180 characters  # noqa: E501

        :param email: The email of this Manufacturer.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def phone(self):
        """Gets the phone of this Manufacturer.  # noqa: E501

        The product manufacturer's business phone number.<br><br><b>Max length</b>: 64 characters  # noqa: E501

        :return: The phone of this Manufacturer.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this Manufacturer.

        The product manufacturer's business phone number.<br><br><b>Max length</b>: 64 characters  # noqa: E501

        :param phone: The phone of this Manufacturer.  # noqa: E501
        :type: str
        """

        self._phone = phone

    @property
    def postal_code(self):
        """Gets the postal_code of this Manufacturer.  # noqa: E501

        The postal code of the product manufacturer's street address.<br><br><b>Max length</b>: 9 characters  # noqa: E501

        :return: The postal_code of this Manufacturer.  # noqa: E501
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """Sets the postal_code of this Manufacturer.

        The postal code of the product manufacturer's street address.<br><br><b>Max length</b>: 9 characters  # noqa: E501

        :param postal_code: The postal_code of this Manufacturer.  # noqa: E501
        :type: str
        """

        self._postal_code = postal_code

    @property
    def state_or_province(self):
        """Gets the state_or_province of this Manufacturer.  # noqa: E501

        The state or province of the product manufacturer's street address.<br><br><b>Max length</b>: 64 characters  # noqa: E501

        :return: The state_or_province of this Manufacturer.  # noqa: E501
        :rtype: str
        """
        return self._state_or_province

    @state_or_province.setter
    def state_or_province(self, state_or_province):
        """Sets the state_or_province of this Manufacturer.

        The state or province of the product manufacturer's street address.<br><br><b>Max length</b>: 64 characters  # noqa: E501

        :param state_or_province: The state_or_province of this Manufacturer.  # noqa: E501
        :type: str
        """

        self._state_or_province = state_or_province

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Manufacturer, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Manufacturer):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Metadata API

    The Metadata API has operations that retrieve configuration details pertaining to the different eBay marketplaces. In addition to marketplace information, the API also has operations that get information that helps sellers list items on eBay.  # noqa: E501

    OpenAPI spec version: v1.10.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SalesTaxJurisdiction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'sales_tax_jurisdiction_id': 'str'
    }

    attribute_map = {
        'sales_tax_jurisdiction_id': 'salesTaxJurisdictionId'
    }

    def __init__(self, sales_tax_jurisdiction_id=None):  # noqa: E501
        """SalesTaxJurisdiction - a model defined in Swagger"""  # noqa: E501
        self._sales_tax_jurisdiction_id = None
        self.discriminator = None
        if sales_tax_jurisdiction_id is not None:
            self.sales_tax_jurisdiction_id = sales_tax_jurisdiction_id

    @property
    def sales_tax_jurisdiction_id(self):
        """Gets the sales_tax_jurisdiction_id of this SalesTaxJurisdiction.  # noqa: E501

        The unique ID for a sales-tax jurisdiction.<br><br><div class=\"msgbox_important\"><p class=\"msgbox_importantInDiv\" data-mc-autonum=\"&lt;b&gt;&lt;span style=&quot;color: #dd1e31;&quot; class=&quot;mcFormatColor&quot;&gt;Important! &lt;/span&gt;&lt;/b&gt;\"><span class=\"autonumber\"><span><b><span style=\"color: #dd1e31;\" class=\"mcFormatColor\">Important!</span></b></span></span> When <code>countryCode</code> is set to <code>US</code>, IDs for all 50 states, Washington, DC, and all US territories will be returned. However, the only <code>salesTaxJurisdictionId</code> values currently supported are:<ul><li><code>AS</code> (American Samoa)</li><li><code>GU</code> (Guam</li><li><code>MP</code> Northern Mariana Islands</li><li><code>PW (Palau)</li><li><code>VI</code> (US Virgin Islands)</li></ul></p></div>  # noqa: E501

        :return: The sales_tax_jurisdiction_id of this SalesTaxJurisdiction.  # noqa: E501
        :rtype: str
        """
        return self._sales_tax_jurisdiction_id

    @sales_tax_jurisdiction_id.setter
    def sales_tax_jurisdiction_id(self, sales_tax_jurisdiction_id):
        """Sets the sales_tax_jurisdiction_id of this SalesTaxJurisdiction.

        The unique ID for a sales-tax jurisdiction.<br><br><div class=\"msgbox_important\"><p class=\"msgbox_importantInDiv\" data-mc-autonum=\"&lt;b&gt;&lt;span style=&quot;color: #dd1e31;&quot; class=&quot;mcFormatColor&quot;&gt;Important! &lt;/span&gt;&lt;/b&gt;\"><span class=\"autonumber\"><span><b><span style=\"color: #dd1e31;\" class=\"mcFormatColor\">Important!</span></b></span></span> When <code>countryCode</code> is set to <code>US</code>, IDs for all 50 states, Washington, DC, and all US territories will be returned. However, the only <code>salesTaxJurisdictionId</code> values currently supported are:<ul><li><code>AS</code> (American Samoa)</li><li><code>GU</code> (Guam</li><li><code>MP</code> Northern Mariana Islands</li><li><code>PW (Palau)</li><li><code>VI</code> (US Virgin Islands)</li></ul></p></div>  # noqa: E501

        :param sales_tax_jurisdiction_id: The sales_tax_jurisdiction_id of this SalesTaxJurisdiction.  # noqa: E501
        :type: str
        """

        self._sales_tax_jurisdiction_id = sales_tax_jurisdiction_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SalesTaxJurisdiction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SalesTaxJurisdiction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
